@@ -38,11 +38,11 @@
 
 APDK_BEGIN_NAMESPACE
 
-extern unsigned long ulMapCONQUEST_CMYK[ 9 * 9 * 9 ];
-extern unsigned long ulMapCONQUEST_ClMlxx[ 9 * 9 * 9 ];
-extern unsigned long ulMapVOLTAIRE_CCM_KCMY[ 9 * 9 * 9 ];
-extern unsigned long ulMapVOLTAIRE_CCM_K[ 9 * 9 * 9 ];
-extern unsigned long ulMapVOLTAIRE_CCM_CMY[ 9 * 9 * 9 ];
+extern uint32_t ulMapCONQUEST_CMYK[ 9 * 9 * 9 ];
+extern uint32_t ulMapCONQUEST_ClMlxx[ 9 * 9 * 9 ];
+extern uint32_t ulMapVOLTAIRE_CCM_KCMY[ 9 * 9 * 9 ];
+extern uint32_t ulMapVOLTAIRE_CCM_K[ 9 * 9 * 9 ];
+extern uint32_t ulMapVOLTAIRE_CCM_CMY[ 9 * 9 * 9 ];
 
 
 Apollo2xxx::Apollo2xxx(SystemServices* pSS, BOOL proto)
@@ -66,7 +66,8 @@ Apollo2xxx::Apollo2xxx(SystemServices* pSS, BOOL proto)
     pMode[SPECIALMODE_INDEX+2] = new Mode2xxxDraftGrayK(); 
     pMode[SPECIALMODE_INDEX+3] = new Mode2xxxDraftColorKCMY();
     pMode[SPECIALMODE_INDEX+4] = new Mode2xxxDraftColorCMY();
-    ModeCount=7;
+    pMode[SPECIALMODE_INDEX+5] = new Mode2xxxBestGrayK();
+    ModeCount=8;
 #else
     ModeCount = 4;
 #endif
@@ -247,6 +248,15 @@ Mode2xxxDraftColorCMY::Mode2xxxDraftColorCMY()
     theQuality = qualityDraft;
     pmQuality = QUALITY_DRAFT;
 }
+
+Mode2xxxBestGrayK::Mode2xxxBestGrayK()
+: GrayMode(ulMapVOLTAIRE_CCM_K)
+{
+   theQuality = qualityPresentation;
+   pmQuality = QUALITY_BEST;
+   BaseResX = BaseResY = 600;
+   ResolutionX[0] = ResolutionY[0] = 600;
+}
 #endif // APDK_AUTODUPLEX
 
 Header2xxx::Header2xxx(Printer* p,PrintContext* pc)
@@ -278,6 +288,14 @@ DRIVER_ERROR Header2xxx::Send()
     err = ConfigureRasterData();
     ERRCHECK;
 
+    if (ResolutionY[0] == 600)
+    {
+        char uom[10];
+        sprintf(uom,"%c%c%c%d%c",ESC,'&','u',thePrintMode->ResolutionY[K],'D');
+        err=thePrinter->Send((const BYTE*)uom, 7 );
+        ERRCHECK;
+    }
+
     err=Graphics();     // start raster graphics and set compression mode
 
 return err;
