@@ -98,6 +98,12 @@ class Mode2xxxDraftColorCMY : public PrintMode
 public:
     Mode2xxxDraftColorCMY();
 }; //Mode2xxxDraftCMYColor
+
+class Mode2xxxBestGrayK : public GrayMode
+{
+public:
+    Mode2xxxBestGrayK();
+}; //Mode2xxxBestGrayK
 #endif // APDK_AUTODUPLEX
 
 #ifdef APDK_PROTO
