@@ -1080,4 +1080,529 @@ const unsigned char HT600x6004level970_open[1024]=
 2,  255,    255,    0
 };
 
+#ifdef APDK_AUTODUPLEX
+
+ // 2001.07.09 mrb: Added for photo glossy mode of DJ970
+ const unsigned char HT1200x1200x1_PhotoPres970_open[1024]=
+ {
+    0 ,   0 ,   0 ,   0 ,
+    0 ,   0 ,   0 ,   0 ,
+    0 ,   1 ,   0 ,   0 ,
+    0 ,   1 ,   0 ,   0 ,
+    0 ,   2 ,   0 ,   0 ,
+    0 ,   2 ,   0 ,   0 ,
+    0 ,   3 ,   0 ,   0 ,
+    0 ,   3 ,   0 ,   0 ,
+    0 ,   4 ,   0 ,   0 ,
+    0 ,   4 ,   0 ,   0 ,
+    0 ,   5 ,   0 ,   0 ,
+    0 ,   5 ,   0 ,   0 ,
+    0 ,   6 ,   0 ,   0 ,
+    0 ,   6 ,   0 ,   0 ,
+    0 ,   7 ,   0 ,   0 ,
+    0 ,   7 ,   0 ,   0 ,
+    0 ,   8 ,   0 ,   0 ,
+    0 ,   8 ,   0 ,   0 ,
+    0 ,   9 ,   0 ,   0 ,
+    0 ,   9 ,   0 ,   0 ,
+    0 ,  10 ,   0 ,   0 ,
+    0 ,  10 ,   0 ,   0 ,
+    0 ,  11 ,   0 ,   0 ,
+    0 ,  11 ,   0 ,   0 ,
+    0 ,  12 ,   0 ,   0 ,
+    0 ,  12 ,   0 ,   0 ,
+    0 ,  13 ,   0 ,   0 ,
+    0 ,  13 ,   0 ,   0 ,
+    0 ,  14 ,   0 ,   0 ,
+    0 ,  14 ,   0 ,   0 ,
+    0 ,  15 ,   0 ,   0 ,
+    0 ,  15 ,   0 ,   0 ,
+    0 ,  16 ,   0 ,   0 ,
+    0 ,  16 ,   0 ,   0 ,
+    0 ,  17 ,   0 ,   0 ,
+    0 ,  17 ,   0 ,   0 ,
+    0 ,  18 ,   0 ,   0 ,
+    0 ,  18 ,   0 ,   0 ,
+    0 ,  19 ,   0 ,   0 ,
+    0 ,  19 ,   0 ,   0 ,
+    0 ,  20 ,   0 ,   0 ,
+    0 ,  20 ,   0 ,   0 ,
+    0 ,  21 ,   0 ,   0 ,
+    0 ,  21 ,   0 ,   0 ,
+    0 ,  22 ,   0 ,   0 ,
+    0 ,  22 ,   0 ,   0 ,
+    0 ,  23 ,   0 ,   0 ,
+    0 ,  23 ,   0 ,   0 ,
+    0 ,  24 ,   0 ,   0 ,
+    0 ,  24 ,   0 ,   0 ,
+    0 ,  25 ,   0 ,   0 ,
+    0 ,  25 ,   0 ,   0 ,
+    0 ,  26 ,   0 ,   0 ,
+    0 ,  26 ,   0 ,   0 ,
+    0 ,  27 ,   0 ,   0 ,
+    0 ,  27 ,   0 ,   0 ,
+    0 ,  28 ,   0 ,   0 ,
+    0 ,  28 ,   0 ,   0 ,
+    0 ,  29 ,   0 ,   0 ,
+    0 ,  29 ,   0 ,   0 ,
+    0 ,  30 ,   0 ,   0 ,
+    0 ,  30 ,   0 ,   0 ,
+    0 ,  31 ,   0 ,   0 ,
+    0 ,  31 ,   0 ,   0 ,
+    0 ,  32 ,   0 ,   0 ,
+    0 ,  32 ,   0 ,   0 ,
+    0 ,  33 ,   0 ,   0 ,
+    0 ,  33 ,   0 ,   0 ,
+    0 ,  34 ,   0 ,   0 ,
+    0 ,  34 ,   0 ,   0 ,
+    0 ,  35 ,   0 ,   0 ,
+    0 ,  35 ,   0 ,   0 ,
+    0 ,  36 ,   0 ,   0 ,
+    0 ,  36 ,   0 ,   0 ,
+    0 ,  37 ,   0 ,   0 ,
+    0 ,  37 ,   0 ,   0 ,
+    0 ,  38 ,   0 ,   0 ,
+    0 ,  38 ,   0 ,   0 ,
+    0 ,  39 ,   0 ,   0 ,
+    0 ,  39 ,   0 ,   0 ,
+    0 ,  40 ,   0 ,   0 ,
+    0 ,  40 ,   0 ,   0 ,
+    0 ,  41 ,   0 ,   0 ,
+    0 ,  41 ,   0 ,   0 ,
+    0 ,  42 ,   0 ,   0 ,
+    0 ,  42 ,   0 ,   0 ,
+    0 ,  43 ,   0 ,   0 ,
+    0 ,  43 ,   0 ,   0 ,
+    0 ,  44 ,   0 ,   0 ,
+    0 ,  44 ,   0 ,   0 ,
+    0 ,  45 ,   0 ,   0 ,
+    0 ,  45 ,   0 ,   0 ,
+    0 ,  46 ,   0 ,   0 ,
+    0 ,  46 ,   0 ,   0 ,
+    0 ,  47 ,   0 ,   0 ,
+    0 ,  47 ,   0 ,   0 ,
+    0 ,  48 ,   0 ,   0 ,
+    0 ,  48 ,   0 ,   0 ,
+    0 ,  49 ,   0 ,   0 ,
+    0 ,  49 ,   0 ,   0 ,
+    0 ,  50 ,   0 ,   0 ,
+    0 ,  50 ,   0 ,   0 ,
+    0 ,  51 ,   0 ,   0 ,
+    0 ,  51 ,   0 ,   0 ,
+    0 ,  52 ,   0 ,   0 ,
+    0 ,  52 ,   0 ,   0 ,
+    0 ,  53 ,   0 ,   0 ,
+    0 ,  53 ,   0 ,   0 ,
+    0 ,  54 ,   0 ,   0 ,
+    0 ,  54 ,   0 ,   0 ,
+    0 ,  55 ,   0 ,   0 ,
+    0 ,  55 ,   0 ,   0 ,
+    0 ,  56 ,   0 ,   0 ,
+    0 ,  56 ,   0 ,   0 ,
+    0 ,  57 ,   0 ,   0 ,
+    0 ,  57 ,   0 ,   0 ,
+    0 ,  58 ,   0 ,   0 ,
+    0 ,  58 ,   0 ,   0 ,
+    0 ,  59 ,   0 ,   0 ,
+    0 ,  59 ,   0 ,   0 ,
+    0 ,  60 ,   0 ,   0 ,
+    0 ,  60 ,   0 ,   0 ,
+    0 ,  61 ,   0 ,   0 ,
+    0 ,  61 ,   0 ,   0 ,
+    0 ,  62 ,   0 ,   0 ,
+    0 ,  62 ,   0 ,   0 ,
+    0 ,  63 ,   0 ,   0 ,
+    0 ,  63 ,   0 ,   0 ,
+    0 ,  64 ,   0 ,   0 ,
+    0 ,  64 ,   0 ,   0 ,
+    0 ,  65 ,   0 ,   0 ,
+    0 ,  65 ,   0 ,   0 ,
+    0 ,  66 ,   0 ,   0 ,
+    0 ,  66 ,   0 ,   0 ,
+    0 ,  67 ,   0 ,   0 ,
+    0 ,  67 ,   0 ,   0 ,
+    0 ,  68 ,   0 ,   0 ,
+    0 ,  68 ,   0 ,   0 ,
+    0 ,  69 ,   0 ,   0 ,
+    0 ,  69 ,   0 ,   0 ,
+    0 ,  70 ,   0 ,   0 ,
+    0 ,  70 ,   0 ,   0 ,
+    0 ,  71 ,   0 ,   0 ,
+    0 ,  71 ,   0 ,   0 ,
+    0 ,  72 ,   0 ,   0 ,
+    0 ,  72 ,   0 ,   0 ,
+    0 ,  73 ,   0 ,   0 ,
+    0 ,  73 ,   0 ,   0 ,
+    0 ,  74 ,   0 ,   0 ,
+    0 ,  74 ,   0 ,   0 ,
+    0 ,  75 ,   0 ,   0 ,
+    0 ,  75 ,   0 ,   0 ,
+    0 ,  76 ,   0 ,   0 ,
+    0 ,  76 ,   0 ,   0 ,
+    0 ,  77 ,   0 ,   0 ,
+    0 ,  77 ,   0 ,   0 ,
+    0 ,  78 ,   0 ,   0 ,
+    0 ,  78 ,   0 ,   0 ,
+    0 ,  79 ,   0 ,   0 ,
+    0 ,  79 ,   0 ,   0 ,
+    0 ,  80 ,   0 ,   0 ,
+    0 ,  80 ,   0 ,   0 ,
+    0 ,  81 ,   0 ,   0 ,
+    0 ,  81 ,   0 ,   0 ,
+    0 ,  82 ,   0 ,   0 ,
+    0 ,  82 ,   0 ,   0 ,
+    0 ,  83 ,   0 ,   0 ,
+    0 ,  83 ,   0 ,   0 ,
+    0 ,  84 ,   0 ,   0 ,
+    0 ,  84 ,   0 ,   0 ,
+    0 ,  85 ,   0 ,   0 ,
+    0 ,  85 ,   0 ,   0 ,
+    0 ,  86 ,   0 ,   0 ,
+    0 ,  86 ,   0 ,   0 ,
+    0 ,  87 ,   0 ,   0 ,
+    0 ,  87 ,   0 ,   0 ,
+    0 ,  88 ,   0 ,   0 ,
+    0 ,  88 ,   0 ,   0 ,
+    0 ,  89 ,   0 ,   0 ,
+    0 ,  89 ,   0 ,   0 ,
+    0 ,  90 ,   0 ,   0 ,
+    0 ,  90 ,   0 ,   0 ,
+    0 ,  91 ,   0 ,   0 ,
+    0 ,  91 ,   0 ,   0 ,
+    0 ,  92 ,   0 ,   0 ,
+    0 ,  92 ,   0 ,   0 ,
+    0 ,  93 ,   0 ,   0 ,
+    0 ,  93 ,   0 ,   0 ,
+    0 ,  94 ,   0 ,   0 ,
+    0 ,  94 ,   0 ,   0 ,
+    0 ,  95 ,   0 ,   0 ,
+    0 ,  95 ,   0 ,   0 ,
+    0 ,  96 ,   0 ,   0 ,
+    0 ,  96 ,   0 ,   0 ,
+    0 ,  97 ,   0 ,   0 ,
+    0 ,  97 ,   0 ,   0 ,
+    0 ,  98 ,   0 ,   0 ,
+    0 ,  98 ,   0 ,   0 ,
+    0 ,  99 ,   0 ,   0 ,
+    0 ,  99 ,   0 ,   0 ,
+    0 , 100 ,   0 ,   0 ,
+    0 , 100 ,   0 ,   0 ,
+    0 , 101 ,   0 ,   0 ,
+    0 , 101 ,   0 ,   0 ,
+    0 , 102 ,   0 ,   0 ,
+    0 , 102 ,   0 ,   0 ,
+    0 , 103 ,   0 ,   0 ,
+    0 , 103 ,   0 ,   0 ,
+    0 , 104 ,   0 ,   0 ,
+    0 , 104 ,   0 ,   0 ,
+    0 , 105 ,   0 ,   0 ,
+    0 , 105 ,   0 ,   0 ,
+    0 , 106 ,   0 ,   0 ,
+    0 , 106 ,   0 ,   0 ,
+    0 , 107 ,   0 ,   0 ,
+    0 , 107 ,   0 ,   0 ,
+    0 , 108 ,   0 ,   0 ,
+    0 , 108 ,   0 ,   0 ,
+    0 , 109 ,   0 ,   0 ,
+    0 , 109 ,   0 ,   0 ,
+    0 , 110 ,   0 ,   0 ,
+    0 , 110 ,   0 ,   0 ,
+    0 , 111 ,   0 ,   0 ,
+    0 , 111 ,   0 ,   0 ,
+    0 , 112 ,   0 ,   0 ,
+    0 , 112 ,   0 ,   0 ,
+    0 , 113 ,   0 ,   0 ,
+    0 , 113 ,   0 ,   0 ,
+    0 , 114 ,   0 ,   0 ,
+    0 , 114 ,   0 ,   0 ,
+    0 , 115 ,   0 ,   0 ,
+    0 , 115 ,   0 ,   0 ,
+    0 , 116 ,   0 ,   0 ,
+    0 , 116 ,   0 ,   0 ,
+    0 , 117 ,   0 ,   0 ,
+    0 , 117 ,   0 ,   0 ,
+    0 , 118 ,   0 ,   0 ,
+    0 , 118 ,   0 ,   0 ,
+    0 , 119 ,   0 ,   0 ,
+    0 , 119 ,   0 ,   0 ,
+    0 , 120 ,   0 ,   0 ,
+    0 , 120 ,   0 ,   0 ,
+    0 , 121 ,   0 ,   0 ,
+    0 , 121 ,   0 ,   0 ,
+    0 , 122 ,   0 ,   0 ,
+    0 , 122 ,   0 ,   0 ,
+    0 , 123 ,   0 ,   0 ,
+    0 , 123 ,   0 ,   0 ,
+    0 , 124 ,   0 ,   0 ,
+    0 , 124 ,   0 ,   0 ,
+    0 , 125 ,   0 ,   0 ,
+    0 , 125 ,   0 ,   0 ,
+    0 , 126 ,   0 ,   0 ,
+    0 , 126 ,   0 ,   0 ,
+    0 , 127 ,   0 ,   0 ,
+    0 , 127 ,   0 ,   0
+ };
+ 
+ // 2001.07.09 mrb: Added for presentation mode of DJ970
+ const unsigned char HT600x600x4_Pres970_open[1024]=
+ {
+    0 ,   0 , 255 ,   0 ,
+    0 ,   0 , 255 ,   0 ,
+    0 ,   2 , 255 ,   0 ,
+    0 ,   3 , 255 ,   0 ,
+    0 ,   4 , 255 ,   0 ,
+    0 ,   5 , 255 ,   0 ,
+    0 ,   6 , 255 ,   0 ,
+    0 ,   7 , 255 ,   0 ,
+    0 ,   8 , 255 ,   0 ,
+    0 ,   9 , 255 ,   0 ,
+    0 ,  10 , 255 ,   0 ,
+    0 ,  11 , 255 ,   0 ,
+    0 ,  12 , 255 ,   0 ,
+    0 ,  13 , 255 ,   0 ,
+    0 ,  14 , 255 ,   0 ,
+    0 ,  15 , 255 ,   0 ,
+    0 ,  16 , 255 ,   0 ,
+    0 ,  17 , 255 ,   0 ,
+    0 ,  18 , 255 ,   0 ,
+    0 ,  19 , 255 ,   0 ,
+    0 ,  20 , 255 ,   0 ,
+    0 ,  21 , 255 ,   0 ,
+    0 ,  22 , 255 ,   0 ,
+    0 ,  23 , 255 ,   0 ,
+    0 ,  24 , 255 ,   0 ,
+    0 ,  25 , 255 ,   0 ,
+    0 ,  26 , 255 ,   0 ,
+    0 ,  27 , 255 ,   0 ,
+    0 ,  28 , 255 ,   0 ,
+    0 ,  29 , 255 ,   0 ,
+    0 ,  30 , 255 ,   0 ,
+    0 ,  31 , 255 ,   0 ,
+    0 ,  32 , 255 ,   0 ,
+    0 ,  33 , 255 ,   0 ,
+    0 ,  34 , 255 ,   0 ,
+    0 ,  35 , 255 ,   0 ,
+    0 ,  36 , 255 ,   0 ,
+    0 ,  37 , 255 ,   0 ,
+    0 ,  38 , 255 ,   0 ,
+    0 ,  39 , 255 ,   0 ,
+    0 ,  40 , 255 ,   0 ,
+    0 ,  41 , 255 ,   0 ,
+    0 ,  42 , 255 ,   0 ,
+    0 ,  43 , 255 ,   0 ,
+    0 ,  44 , 255 ,   0 ,
+    0 ,  45 , 255 ,   0 ,
+    0 ,  46 , 255 ,   0 ,
+    0 ,  47 , 255 ,   0 ,
+    0 ,  48 , 255 ,   0 ,
+    0 ,  49 , 255 ,   0 ,
+    0 ,  50 , 255 ,   0 ,
+    0 ,  51 , 255 ,   0 ,
+    0 ,  52 , 255 ,   0 ,
+    0 ,  53 , 255 ,   0 ,
+    0 ,  54 , 255 ,   0 ,
+    0 ,  55 , 255 ,   0 ,
+    0 ,  56 , 255 ,   0 ,
+    0 ,  57 , 255 ,   0 ,
+    0 ,  58 , 255 ,   0 ,
+    0 ,  59 , 255 ,   0 ,
+    0 ,  60 , 255 ,   0 ,
+    0 ,  61 , 255 ,   0 ,
+    0 ,  62 , 255 ,   0 ,
+    0 ,  63 , 255 ,   0 ,
+    0 ,  64 , 255 ,   0 ,
+    0 ,  65 , 255 ,   0 ,
+    0 ,  66 , 255 ,   0 ,
+    0 ,  67 , 255 ,   0 ,
+    0 ,  68 , 255 ,   0 ,
+    0 ,  69 , 255 ,   0 ,
+    0 ,  70 , 255 ,   0 ,
+    0 ,  71 , 255 ,   0 ,
+    0 ,  72 , 255 ,   0 ,
+    0 ,  73 , 255 ,   0 ,
+    0 ,  74 , 255 ,   0 ,
+    0 ,  75 , 255 ,   0 ,
+    0 ,  76 , 255 ,   0 ,
+    0 ,  77 , 255 ,   0 ,
+    0 ,  78 , 255 ,   0 ,
+    0 ,  79 , 255 ,   0 ,
+    0 ,  80 , 255 ,   0 ,
+    0 ,  81 , 255 ,   0 ,
+    0 ,  82 , 255 ,   0 ,
+    0 ,  83 , 255 ,   0 ,
+    0 ,  84 , 255 ,   0 ,
+    0 ,  85 , 255 ,   0 ,
+    0 ,  86 , 255 ,   0 ,
+    0 ,  87 , 255 ,   0 ,
+    0 ,  88 , 255 ,   0 ,
+    0 ,  89 , 255 ,   0 ,
+    0 ,  90 , 255 ,   0 ,
+    0 ,  91 , 255 ,   0 ,
+    0 ,  92 , 255 ,   0 ,
+    0 ,  93 , 255 ,   0 ,
+    0 ,  94 , 255 ,   0 ,
+    0 ,  95 , 255 ,   0 ,
+    0 ,  96 , 255 ,   0 ,
+    0 ,  97 , 255 ,   0 ,
+    0 ,  98 , 255 ,   0 ,
+    0 ,  99 , 255 ,   0 ,
+    0 , 100 , 255 ,   0 ,
+    0 , 101 , 255 ,   0 ,
+    0 , 102 , 255 ,   0 ,
+    0 , 103 , 255 ,   0 ,
+    0 , 104 , 255 ,   0 ,
+    0 , 105 , 255 ,   0 ,
+    0 , 106 , 255 ,   0 ,
+    0 , 107 , 255 ,   0 ,
+    0 , 108 , 255 ,   0 ,
+    0 , 109 , 255 ,   0 ,
+    0 , 110 , 255 ,   0 ,
+    0 , 111 , 255 ,   0 ,
+    0 , 112 , 255 ,   0 ,
+    0 , 113 , 255 ,   0 ,
+    0 , 114 , 255 ,   0 ,
+    0 , 115 , 255 ,   0 ,
+    0 , 116 , 255 ,   0 ,
+    0 , 117 , 255 ,   0 ,
+    0 , 118 , 255 ,   0 ,
+    0 , 119 , 255 ,   0 ,
+    0 , 120 , 255 ,   0 ,
+    0 , 121 , 255 ,   0 ,
+    0 , 122 , 255 ,   0 ,
+    0 , 123 , 255 ,   0 ,
+    0 , 124 , 255 ,   0 ,
+    0 , 125 , 255 ,   0 ,
+    0 , 126 , 255 ,   0 ,
+    0 , 127 , 255 ,   0 ,
+    0 , 129 , 255 ,   0 ,
+    0 , 131 , 255 ,   0 ,
+    0 , 133 , 255 ,   0 ,
+    0 , 135 , 255 ,   0 ,
+    0 , 137 , 255 ,   0 ,
+    0 , 139 , 255 ,   0 ,
+    0 , 141 , 255 ,   0 ,
+    0 , 143 , 255 ,   0 ,
+    0 , 145 , 255 ,   0 ,
+    0 , 147 , 255 ,   0 ,
+    0 , 149 , 255 ,   0 ,
+    0 , 151 , 255 ,   0 ,
+    0 , 153 , 255 ,   0 ,
+    0 , 155 , 255 ,   0 ,
+    0 , 157 , 255 ,   0 ,
+    0 , 159 , 255 ,   0 ,
+    0 , 161 , 255 ,   0 ,
+    0 , 163 , 255 ,   0 ,
+    0 , 165 , 255 ,   0 ,
+    0 , 167 , 255 ,   0 ,
+    0 , 169 , 255 ,   0 ,
+    0 , 171 , 255 ,   0 ,
+    0 , 173 , 255 ,   0 ,
+    0 , 175 , 255 ,   0 ,
+    0 , 177 , 255 ,   0 ,
+    0 , 179 , 255 ,   0 ,
+    0 , 181 , 255 ,   0 ,
+    0 , 183 , 255 ,   0 ,
+    0 , 185 , 255 ,   0 ,
+    0 , 187 , 255 ,   0 ,
+    0 , 189 , 255 ,   0 ,
+    0 , 191 , 255 ,   0 ,
+    0 , 193 , 255 ,   0 ,
+    0 , 195 , 255 ,   0 ,
+    0 , 197 , 255 ,   0 ,
+    0 , 199 , 255 ,   0 ,
+    0 , 201 , 255 ,   0 ,
+    0 , 203 , 255 ,   0 ,
+    0 , 205 , 255 ,   0 ,
+    0 , 207 , 255 ,   0 ,
+    0 , 209 , 255 ,   0 ,
+    0 , 211 , 255 ,   0 ,
+    0 , 213 , 255 ,   0 ,
+    0 , 215 , 255 ,   0 ,
+    0 , 217 , 255 ,   0 ,
+    0 , 219 , 255 ,   0 ,
+    0 , 221 , 255 ,   0 ,
+    0 , 223 , 255 ,   0 ,
+    0 , 225 , 255 ,   0 ,
+    0 , 227 , 255 ,   0 ,
+    0 , 229 , 255 ,   0 ,
+    0 , 231 , 255 ,   0 ,
+    0 , 233 , 255 ,   0 ,
+    0 , 235 , 255 ,   0 ,
+    0 , 237 , 255 ,   0 ,
+    0 , 239 , 255 ,   0 ,
+    0 , 241 , 255 ,   0 ,
+    0 , 243 , 255 ,   0 ,
+    0 , 245 , 255 ,   0 ,
+    0 , 247 , 255 ,   0 ,
+    0 , 249 , 255 ,   0 ,
+    0 , 251 , 255 ,   0 ,
+    0 , 253 , 255 ,   0 ,
+    0 , 255 , 255 ,   0 ,
+    1 ,   1 , 255 ,   0 ,
+    1 ,   3 , 255 ,   0 ,
+    1 ,   5 , 255 ,   0 ,
+    1 ,   7 , 255 ,   0 ,
+    1 ,   9 , 255 ,   0 ,
+    1 ,  11 , 255 ,   0 ,
+    1 ,  13 , 255 ,   0 ,
+    1 ,  15 , 255 ,   0 ,
+    1 ,  17 , 255 ,   0 ,
+    1 ,  19 , 255 ,   0 ,
+    1 ,  21 , 255 ,   0 ,
+    1 ,  23 , 255 ,   0 ,
+    1 ,  25 , 255 ,   0 ,
+    1 ,  27 , 255 ,   0 ,
+    1 ,  29 , 255 ,   0 ,
+    1 ,  31 , 255 ,   0 ,
+    1 ,  33 , 255 ,   0 ,
+    1 ,  35 , 255 ,   0 ,
+    1 ,  37 , 255 ,   0 ,
+    1 ,  39 , 255 ,   0 ,
+    1 ,  41 , 255 ,   0 ,
+    1 ,  43 , 255 ,   0 ,
+    1 ,  45 , 255 ,   0 ,
+    1 ,  47 , 255 ,   0 ,
+    1 ,  49 , 255 ,   0 ,
+    1 ,  51 , 255 ,   0 ,
+    1 ,  53 , 255 ,   0 ,
+    1 ,  55 , 255 ,   0 ,
+    1 ,  57 , 255 ,   0 ,
+    1 ,  59 , 255 ,   0 ,
+    1 ,  61 , 255 ,   0 ,
+    1 ,  63 , 255 ,   0 ,
+    1 ,  65 , 255 ,   0 ,
+    1 ,  67 , 255 ,   0 ,
+    1 ,  69 , 255 ,   0 ,
+    1 ,  71 , 255 ,   0 ,
+    1 ,  73 , 255 ,   0 ,
+    1 ,  75 , 255 ,   0 ,
+    1 ,  77 , 255 ,   0 ,
+    1 ,  79 , 255 ,   0 ,
+    1 ,  81 , 255 ,   0 ,
+    1 ,  83 , 255 ,   0 ,
+    1 ,  85 , 255 ,   0 ,
+    1 ,  87 , 255 ,   0 ,
+    1 ,  89 , 255 ,   0 ,
+    1 ,  91 , 255 ,   0 ,
+    1 ,  93 , 255 ,   0 ,
+    1 ,  95 , 255 ,   0 ,
+    1 ,  97 , 255 ,   0 ,
+    1 ,  99 , 255 ,   0 ,
+    1 , 101 , 255 ,   0 ,
+    1 , 103 , 255 ,   0 ,
+    1 , 105 , 255 ,   0 ,
+    1 , 107 , 255 ,   0 ,
+    1 , 109 , 255 ,   0 ,
+    1 , 111 , 255 ,   0 ,
+    1 , 113 , 255 ,   0 ,
+    1 , 115 , 255 ,   0 ,
+    1 , 117 , 255 ,   0 ,
+    1 , 119 , 255 ,   0 ,
+    1 , 121 , 255 ,   0 ,
+    1 , 123 , 255 ,   0 ,
+    1 , 125 , 255 ,   0 ,
+    1 , 127 , 255 ,   0
+};
+#endif // APDK_AUTODUPLEX
+
 APDK_END_NAMESPACE
