@@ -122,7 +122,7 @@ const PrintContext::PaperSizeMetrics PrintContext::PSM[MAX_PAPER_SIZE] =
 
     //  HAGAKI = 100 x 148mm = 3.94 x 5.83 in.
     {
-        (float)3.94, (float)5.83,  (float)3.44, (float)5.33,    (float)0.125
+        (float)3.94, (float)5.83,  (float)3.69, (float)5.58,    (float)0.125
     },
 
     // A6_WITH_TEAR_OFF_TAB = 105mm x 148mm = 4.13 x 5.83 in.
@@ -159,6 +159,11 @@ const PrintContext::PaperSizeMetrics PrintContext::PSM[MAX_PAPER_SIZE] =
     // FLSA = 8.5 x 13 in.
     {
         (float)8.5, (float)13,   (float)8.00,  (float)12.375,   (float)0.125
+    },
+
+    // CUSTOM_SIZE
+    {
+        (float)0.0, (float)0.0,   (float)0.0,  (float)0.0,   (float)0.125
     }
 #endif
 
@@ -205,7 +210,9 @@ PrintContext::PrintContext
     thePaperSize(ps),
     MadeCompGrayMode(FALSE)
 #ifdef APDK_AUTODUPLEX
-      , DuplexMode(DUPLEXMODE_NONE)
+    , DuplexMode(DUPLEXMODE_NONE),
+    CustomWidth(0.0),
+    CustomHeight(0.0)
 #endif
 
 {
@@ -222,6 +229,8 @@ PrintContext::PrintContext
 
     m_mtReqMediaType = eMedia;  // for use by Header - Malibu defect
 
+    m_MediaSource = sourceTrayAuto;
+
     if (!pSS->IOMode.bDevID)     // SystemServices couldn't establish good DevID
     {
         // changed - DWK & JLM  setpixelsperrow always returns NO_ERROR when CurrentMode
@@ -327,12 +336,24 @@ DRIVER_ERROR PrintContext::SetMode(unsigned int ModeIndex)
 ******************************************************************************/
 DRIVER_ERROR PrintContext::SelectDefaultMode()
 {
-    return SelectPrintMode(QUALITY_NORMAL, MEDIA_PLAIN, COLOR, FALSE);
+//    return SelectPrintMode(QUALITY_NORMAL, MEDIA_PLAIN, COLOR, FALSE);
+    DRIVER_ERROR err = SelectPrintMode (QUALITY_NORMAL, MEDIA_PLAIN, COLOR, FALSE);
+    if (err == WARN_MODE_MISMATCH)
+    {
+        QUALITY_MODE    eq;
+        MEDIATYPE       em;
+        BOOL            bText;
+        COLORMODE    eColorMode = COLOR;
+        GetPrintModeSettings (eq, em, eColorMode, bText);
+        if (eColorMode == GREY_K)
+            err = NO_ERROR;
+    }
+    return err;
 } //SelectDefaultMode
 
 
 //SelectPrintMode
-//!Select a print mode base in independent parameters
+//!Select a print mode based on independent parameters
 /*!
 Select a print mode base on Quality, Media, ColorMode, and support of
 DeviceText.  Method may change parameters depending on what the printer
@@ -769,12 +790,18 @@ float PrintContext::PhysicalPageSizeX()   // returned in inches
 
     float   xOverSpray, yOverSpray;
 
+#ifdef APDK_AUTODUPLEX
+    float PhysicalPageX = (thePaperSize == CUSTOM_SIZE) ? CustomWidth : PSM[thePaperSize].fPhysicalPageX;
+#else
+    float PhysicalPageX = PSM[thePaperSize].fPhysicalPageX;
+#endif
+
     if (bDoFullBleed && (thePrinter->FullBleedCapable (thePaperSize, &xOverSpray, &yOverSpray)))
     {
-        return (PSM[thePaperSize].fPhysicalPageX + xOverSpray);
+        return (PhysicalPageX + xOverSpray);
     }
 
-    return PSM[ thePaperSize ].fPhysicalPageX;
+    return PhysicalPageX;
 } //PhysicalPageSizeX
 
 
@@ -788,12 +815,18 @@ float PrintContext::PhysicalPageSizeY()   // returned in inches
 
     float   xOverSpray, yOverSpray;
 
+#ifdef APDK_AUTODUPLEX
+    float PhysicalPageY = (thePaperSize == CUSTOM_SIZE) ? CustomHeight : PSM[thePaperSize].fPhysicalPageY;
+#else
+    float PhysicalPageY = PSM[thePaperSize].fPhysicalPageY;
+#endif
+
     if (bDoFullBleed && (thePrinter->FullBleedCapable (thePaperSize, &xOverSpray, &yOverSpray)))
     {
-        return (PSM[thePaperSize].fPhysicalPageY + yOverSpray);
+        return (PhysicalPageY + yOverSpray);
     }
 
-    return PSM[ thePaperSize ].fPhysicalPageY;
+    return PhysicalPageY;
 } //PhysicalPageSizeY
 
 
@@ -820,18 +853,26 @@ float PrintContext::printablewidth()
 
     float   xOverSpray, yOverSpray;
 
+#ifdef APDK_AUTODUPLEX
+    float PhysicalPageX = (thePaperSize == CUSTOM_SIZE) ? CustomWidth : PSM[thePaperSize].fPhysicalPageX;
+    float PrintablePageX = (thePaperSize == CUSTOM_SIZE) ? CustomWidth - (0.25+0.25) : PSM[thePaperSize].fPrintablePageX;
+#else
+    float PhysicalPageX = PSM[thePaperSize].fPhysicalPageX;
+    float PrintablePageX = PSM[thePaperSize].fPrintablePageX;
+#endif
+
     if (bDoFullBleed && (thePrinter->FullBleedCapable (thePaperSize, &xOverSpray, &yOverSpray)))
     {
-        return (PSM[thePaperSize].fPhysicalPageX + xOverSpray);
+        return (PhysicalPageX + xOverSpray);
     }
 
     float   fMargins[4];    // Left, Right, Top, Bottom margin values
 
     if (!(thePrinter->GetMargins (thePaperSize, fMargins)))
     {
-        return PSM[ thePaperSize ].fPrintablePageX;
+        return PrintablePageX;
     }
-    return (PSM[thePaperSize].fPhysicalPageX - (fMargins[0] + fMargins[1]));
+    return (PhysicalPageX - (fMargins[0] + fMargins[1]));
 } //printablewidth
 
 
@@ -861,12 +902,20 @@ float PrintContext::printableheight()
 
     float   xOverSpray, yOverSpray;
 
+#ifdef APDK_AUTODUPLEX
+    float PhysicalPageY = (thePaperSize == CUSTOM_SIZE) ? CustomHeight : PSM[thePaperSize].fPhysicalPageY;
+    float PrintablePageY = (thePaperSize == CUSTOM_SIZE) ? CustomHeight - (0.125+0.5) : PSM[thePaperSize].fPrintablePageY;
+#else
+    float PhysicalPageY = PSM[thePaperSize].fPhysicalPageY;
+    float PrintablePageY = PSM[thePaperSize].fPrintablePageY;
+#endif
+
     if (bDoFullBleed  && (thePrinter->FullBleedCapable (thePaperSize, &xOverSpray, &yOverSpray)))
     {
         if (thePaperSize == PHOTO_SIZE || thePaperSize == A6_WITH_TEAR_OFF_TAB)
-            return (PSM[thePaperSize].fPhysicalPageY + yOverSpray);
+            return (PhysicalPageY + yOverSpray);
         else
-            return (PSM[thePaperSize].fPhysicalPageY - (float) 0.5);
+            return (PhysicalPageY - (float) 0.5);
     }
 
 /*
@@ -875,15 +924,17 @@ float PrintContext::printableheight()
  *  But bottom margin on 6xx based printers is a little larger, ~0.58 inch.
  *  We should do per-printer get bottom margin/left margin to adjust printable height
  *  and printable width.
+ *
+ *  (Note, a 0.67 inch bottom margin is now in GetMargins() for 6xx based printers. des)
  */
 
     float   fMargins[4];    // Left, Right, Top, Bottom margin values
 
     if (!(thePrinter->GetMargins (thePaperSize, fMargins)))
     {
-        return PSM[ thePaperSize ].fPrintablePageY;
+        return PrintablePageY;
     }
-    return (PSM[thePaperSize].fPhysicalPageY - (fMargins[2] + fMargins[3]));
+    return (PhysicalPageY - (fMargins[2] + fMargins[3]));
 } //printableheight
 
 
@@ -903,7 +954,11 @@ float PrintContext::PrintableStartX() // returned in inches
     }
 
     // this return value centers the printable page horizontally on the physical page
-    float physwidth =  PSM[ thePaperSize ].fPhysicalPageX;
+#ifdef APDK_AUTODUPLEX
+    float physwidth = (thePaperSize == CUSTOM_SIZE) ? CustomWidth : PSM[thePaperSize].fPhysicalPageX;
+#else
+    float physwidth = PSM[thePaperSize].fPhysicalPageX;
+#endif
     float printable =  printablewidth (); // PSM[ thePaperSize ].fPrintablePageX;
     return ((physwidth - printable) / (float)2.0 );
 } //PrintableStartX
@@ -924,6 +979,13 @@ float PrintContext::PrintableStartY() // returned in inches
         return (0.0);
     }
 
+    float   fMargins[4];    // Left, Right, Top, Bottom margin values
+
+    if ((thePrinter->GetMargins (thePaperSize, fMargins)))
+    {
+        return (fMargins[2]);
+    }
+
     return PSM[ thePaperSize ].fPrintableStartY;
 } //PrintableStartY
 
@@ -1349,7 +1411,12 @@ DRIVER_ERROR PrintContext::SetPaperSize (PAPER_SIZE ps, BOOL bFullBleed)
     DRIVER_ERROR    psError = NO_ERROR;
     if ((psMandatoryPS = thePrinter->MandatoryPaperSize()) != UNSUPPORTED_SIZE)
     {
-        if ((PSM[ps].fPhysicalPageX > PSM[psMandatoryPS].fPhysicalPageX))
+#ifdef APDK_AUTODUPLEX
+        float ReqPhysWidth = (ps == CUSTOM_SIZE) ? CustomWidth : PSM[ps].fPhysicalPageX;
+#else
+        float ReqPhysWidth = PSM[ps].fPhysicalPageX;
+#endif
+        if ((ReqPhysWidth > PSM[psMandatoryPS].fPhysicalPageX))
               // only use the page width.  We are not so concerned about the height.
               // if we use both then we have a problem with paper sizes that shorter,
               // but wider or taller and narrower - example A6 and PHOTO.  If you set
@@ -1535,10 +1602,6 @@ BOOL PrintContext::SelectDuplexPrinting
     {
         return FALSE;
     }
-    if (duplexmode == DUPLEXMODE_NONE)
-    {
-        return TRUE;
-    }
     if (!CurrentMode->bDuplexCapable)
     {
         return FALSE;
@@ -1559,6 +1622,28 @@ DUPLEXMODE PrintContext::QueryDuplexMode ()
     }
     return CurrentMode->QueryDuplexMode ();
 } //QueryDuplexMode
+
+/*!
+Determine if the selected printer requires rasters to be rotated by 180 degrees
+for printing on the back side in a duplex job.
+*/
+BOOL    PrintContext::RotateImageForBackPage ()
+{
+    if (thePrinter == NULL)
+        return TRUE;
+    return thePrinter->RotateImageForBackPage ();
+}
+
+/*!
+Set custom paper size physical width and height in inches. Used with custom paper size only.
+*/
+BOOL  PrintContext::SetCustomSize (float width, float height)
+{
+    CustomWidth=width;
+    CustomHeight=height;
+    return NO_ERROR;
+}
+
 #endif //APDK_AUTODUPLEX
 
 
@@ -1650,7 +1735,7 @@ DRIVER_ERROR PrintContext::SetCompGrayMode
 {
     DRIVER_ERROR err;
     ColorMatcher* pColorMatcher;
-    unsigned long* graymap = (unsigned long*)pSS->AllocMem(sizeof(unsigned long)*9*9*9);
+    uint32_t* graymap = (uint32_t*)pSS->AllocMem(sizeof(uint32_t)*9*9*9);
 
     if (graymap==NULL)
     {
@@ -1752,4 +1837,27 @@ DRIVER_ERROR PrintContext::SetCompGrayMode
     return NO_ERROR;
 } //SetCompGrayMode
 
+// SetMediaSource
+//! Select input media source bin
+/*!
+Used to set the bin number from which media will be loaded by the printer. This
+is relevant for those printers that have multiple input bins. All other printers
+will ignore the bin number. The typical bin numbers are
+    1 - Upper Tray
+    4 - Lower Tray
+    7 - Auto Select
+Any value between 1 and 50 is valid where there are more than 2 trays.
+******************************************************************************/
+
+DRIVER_ERROR PrintContext::SetMediaSource
+(
+    MediaSource num             //!< Bin Number
+)
+{
+    if ((num > sourceTrayMax) || (num < sourceTrayMin))
+	     return WARN_INVALID_MEDIA_SOURCE;
+    m_MediaSource = num;
+    return NO_ERROR;
+}
+
 APDK_END_NAMESPACE
