@@ -65,6 +65,7 @@ friend class RasterSender;    // access to current printmode
 friend class HeaderAladdin;  // to use GUITopMargin
 friend class Header895;
 friend class Tester;
+friend class Header850;
 
 public:
     PrintContext(SystemServices *pSysServ,
@@ -112,7 +113,10 @@ public:
     Returns the identifying string for the currently selected print mode.
     This method now returns an empty string for every print mode.
     */
-    char* GetModeName() { return(""); }
+    const char *GetModeName ()
+    {
+        return ("");
+    }
 
     DRIVER_ERROR GetPrintModeSettings(
         QUALITY_MODE& eQuality,
@@ -195,12 +199,17 @@ public:
 
     DeviceRegistry* DR;     // unprotected for replay system
 
+    DRIVER_ERROR SetMediaSource(MediaSource num);
+    MediaSource GetMediaSource() { return m_MediaSource; }
+
     // needed for testing
 //    PEN_TYPE GetCompatiblePen(unsigned int num);    // get CompatiblePens of Printer
 
 #ifdef APDK_AUTODUPLEX
     BOOL  SelectDuplexPrinting (DUPLEXMODE duplexmode);
     DUPLEXMODE QueryDuplexMode ();
+    BOOL  RotateImageForBackPage ();
+    BOOL  SetCustomSize (float width, float height);
 #endif
 
 #ifdef APDK_PROTO
@@ -269,8 +278,12 @@ private:
 
 #ifdef APDK_AUTODUPLEX
     DUPLEXMODE  DuplexMode;
+    float CustomWidth;       // custom physical page width
+    float CustomHeight;      // custom physical page height
 #endif
 
+    MediaSource m_MediaSource;
+
 #ifdef APDK_CAPTURE
     void Capture_PrintContext(unsigned int InputPixelsPerRow, unsigned int OutputPixelsPerRow,
                               PAPER_SIZE ps,IO_MODE IOMode);
