@@ -40,8 +40,8 @@
 
 APDK_BEGIN_NAMESPACE
 
-extern unsigned long ulMapVOLTAIRE_CCM_CMY[ 9 * 9 * 9 ];
-extern unsigned long ulMapVOLTAIRE_CCM_K[ 9 * 9 * 9 ];
+extern uint32_t ulMapVOLTAIRE_CCM_CMY[ 9 * 9 * 9 ];
+extern uint32_t ulMapVOLTAIRE_CCM_K[ 9 * 9 * 9 ];
 
 DJ350::DJ350(SystemServices* pSS, int numfonts, BOOL proto)
            : DJ600 (pSS, proto)
@@ -51,7 +51,7 @@ DJ350::DJ350(SystemServices* pSS, int numfonts, BOOL proto)
 //    pMode[SPECIALMODE_INDEX] = new Mode350CPhoto (CMYMap);
 
 #ifdef APDK_AUTODUPLEX
-    ModeCount = 4;
+    ModeCount = 5;
 #else
     ModeCount = 2;
 #endif
@@ -60,7 +60,7 @@ DJ350::DJ350(SystemServices* pSS, int numfonts, BOOL proto)
 }
 
 #if 0
-Mode350KPhoto::Mode350KPhoto (unsigned long *map)
+Mode350KPhoto::Mode350KPhoto (uint32_t *map)
     : PrintMode (map)
 {
     theQuality = qualityPresentation;
@@ -75,7 +75,7 @@ Mode350KPhoto::Mode350KPhoto (unsigned long *map)
 //    strcpy (ModeName, "BlackBest");
 }
 
-Mode350CPhoto::Mode350CPhoto (unsigned long *map)
+Mode350CPhoto::Mode350CPhoto (uint32_t *map)
     : PrintMode (map)
 {
     theQuality = qualityPresentation;
