@@ -37,8 +37,8 @@
 
 APDK_BEGIN_NAMESPACE
 
-extern unsigned long ulMapVOLTAIRE_CCM_K[ 9 * 9 * 9 ];
-extern unsigned long ulMapVOLTAIRE_CCM_CMY[ 9 * 9 * 9 ];
+extern uint32_t ulMapVOLTAIRE_CCM_K[ 9 * 9 * 9 ];
+extern uint32_t ulMapVOLTAIRE_CCM_CMY[ 9 * 9 * 9 ];
 //
 // ** DJ600:Printer CLASS **
 //
@@ -66,6 +66,15 @@ Mode600DraftGrayK::Mode600DraftGrayK()
    theQuality = qualityDraft;
    pmQuality = QUALITY_DRAFT;
 }
+
+Mode600BestGrayK::Mode600BestGrayK()
+: GrayMode(ulMapVOLTAIRE_CCM_K)
+{
+   theQuality = qualityPresentation;
+   pmQuality = QUALITY_BEST;
+   BaseResX = BaseResY = 600;
+   ResolutionX[0] = ResolutionY[0] = 600;
+}
 #endif // APDK_AUTODUPLEX
 
 DJ600::DJ600(SystemServices* pSS, BOOL proto)
@@ -88,6 +97,7 @@ DJ600::DJ600(SystemServices* pSS, BOOL proto)
 #ifdef APDK_AUTODUPLEX
     pMode[SPECIALMODE_INDEX] = new Mode600DraftGrayK(); 
     pMode[SPECIALMODE_INDEX+1] = new Mode600DraftColor();
+    pMode[SPECIALMODE_INDEX+2] = new Mode600BestGrayK();
 #endif
 
 DBG1("DeskJet 600 created\n");
