@@ -69,6 +69,12 @@ class Mode600DraftColor : public PrintMode
 public:
     Mode600DraftColor();
 }; //Mode600DraftColor
+
+class Mode600BestGrayK : public GrayMode
+{
+public:
+    Mode600BestGrayK();
+}; //Mode600BestGrayK
 #endif // APDK_AUTODUPLEX
 
 #ifdef APDK_PROTO
