@@ -36,11 +36,11 @@
 
 APDK_BEGIN_NAMESPACE
 
-extern unsigned long ulMapCONQUEST_CMYK[ 9 * 9 * 9 ];
-extern unsigned long ulMapCONQUEST_ClMlxx[ 9 * 9 * 9 ];
-extern unsigned long ulMapVOLTAIRE_CCM_KCMY[ 9 * 9 * 9 ];
-extern unsigned long ulMapVOLTAIRE_CCM_K[ 9 * 9 * 9 ];
-extern unsigned long ulMapVOLTAIRE_CCM_CMY[ 9 * 9 * 9 ];
+extern uint32_t ulMapCONQUEST_CMYK[ 9 * 9 * 9 ];
+extern uint32_t ulMapCONQUEST_ClMlxx[ 9 * 9 * 9 ];
+extern uint32_t ulMapVOLTAIRE_CCM_KCMY[ 9 * 9 * 9 ];
+extern uint32_t ulMapVOLTAIRE_CCM_K[ 9 * 9 * 9 ];
+extern uint32_t ulMapVOLTAIRE_CCM_CMY[ 9 * 9 * 9 ];
 
 
 DJ630::DJ630(SystemServices* pSS, BOOL proto)
@@ -67,7 +67,8 @@ DJ630::DJ630(SystemServices* pSS, BOOL proto)
     pMode[SPECIALMODE_INDEX+2] = new Mode630DraftGrayK(); 
     pMode[SPECIALMODE_INDEX+3] = new Mode630DraftColorKCMY();
     pMode[SPECIALMODE_INDEX+4] = new Mode630DraftColorCMY();
-    ModeCount=7;
+    pMode[SPECIALMODE_INDEX+5] = new Mode630BestGrayK();
+    ModeCount=8;
 #else
     ModeCount = 4;
 #endif
@@ -81,7 +82,7 @@ PEN_TYPE DJ630::DefaultPenSet()
     return COLOR_PEN;
 }
 
-GrayMode630::GrayMode630(unsigned long *map)
+GrayMode630::GrayMode630(uint32_t *map)
 : GrayMode(map)
 {
     CompatiblePens[1] = BLACK_PEN;
@@ -247,6 +248,15 @@ Mode630DraftColorCMY::Mode630DraftColorCMY()
     theQuality = qualityDraft;
     pmQuality = QUALITY_DRAFT;
 }
+
+Mode630BestGrayK::Mode630BestGrayK()
+: GrayMode(ulMapVOLTAIRE_CCM_K)
+{
+   theQuality = qualityPresentation;
+   pmQuality = QUALITY_BEST;
+   BaseResX = BaseResY = 600;
+   ResolutionX[0] = ResolutionY[0] = 600;
+}
 #endif // APDK_AUTODUPLEX
 
 Header630::Header630(Printer* p,PrintContext* pc)
@@ -276,6 +286,14 @@ DRIVER_ERROR Header630::Send()
     err = ConfigureRasterData();
     ERRCHECK;
 
+    if (ResolutionY[0] == 600)
+    {
+        char uom[10];
+        sprintf(uom,"%c%c%c%d%c",ESC,'&','u',thePrintMode->ResolutionY[K],'D');
+        err=thePrinter->Send((const BYTE*)uom, 7 );
+        ERRCHECK;
+    }
+
     err=Graphics();     // start raster graphics and set compression mode
 
 return err;
