@@ -78,7 +78,7 @@ public:
 class GrayMode630 : public GrayMode
 {
 public:
-    GrayMode630(unsigned long *map);
+    GrayMode630(uint32_t *map);
 }; //GrayMode630
 
 #ifdef APDK_AUTODUPLEX
@@ -99,6 +99,12 @@ class Mode630DraftColorCMY : public PrintMode
 public:
     Mode630DraftColorCMY();
 }; //Mode630DraftCMYColor
+
+class Mode630BestGrayK : public GrayMode
+{
+public:
+    Mode630BestGrayK();
+}; //Mode630BestGrayK
 #endif // APDK_AUTODUPLEX
 
 #ifdef APDK_PROTO
