@@ -37,9 +37,9 @@
 
 APDK_BEGIN_NAMESPACE
 
-extern unsigned long ulMapVOLTAIRE_CCM_KCMY[ 9 * 9 * 9 ];
-extern unsigned long ulMapVOLTAIRE_CCM_K[ 9 * 9 * 9 ];
-extern unsigned long ulMapVOLTAIRE_CCM_CMY[ 9 * 9 * 9 ];
+extern uint32_t ulMapVOLTAIRE_CCM_KCMY[ 9 * 9 * 9 ];
+extern uint32_t ulMapVOLTAIRE_CCM_K[ 9 * 9 * 9 ];
+extern uint32_t ulMapVOLTAIRE_CCM_CMY[ 9 * 9 * 9 ];
 //
 // ** DJ660:Printer CLASS **
 //
@@ -62,7 +62,8 @@ DBG1("DJ660::VerifyPenInfo(): called\n");
     pMode[SPECIALMODE_INDEX] = new Mode660Draft();
 #ifdef APDK_AUTODUPLEX
     pMode[SPECIALMODE_INDEX+1] = new Mode660DraftGrayK();
-    ModeCount=4;
+    pMode[SPECIALMODE_INDEX+2] = new Mode660BestGrayK();
+    ModeCount=5;
 #else
     ModeCount=3;
 #endif
@@ -92,6 +93,15 @@ Mode660DraftGrayK::Mode660DraftGrayK()
    theQuality = qualityDraft;
    pmQuality = QUALITY_DRAFT;
 }
+
+Mode660BestGrayK::Mode660BestGrayK()
+: GrayMode(ulMapVOLTAIRE_CCM_K)
+{
+   theQuality = qualityPresentation;
+   pmQuality = QUALITY_BEST;
+   BaseResX = BaseResY = 600;
+   ResolutionX[0] = ResolutionY[0] = 600;
+}
 #endif // APDK_AUTODUPLEX
 
 Header* DJ660::SelectHeader(PrintContext* pc)
