@@ -63,6 +63,12 @@ class Mode660DraftGrayK : public GrayMode
 public:
     Mode660DraftGrayK();
 }; //Mode660DraftGrayK
+
+class Mode660BestGrayK : public GrayMode
+{
+public:
+    Mode660BestGrayK();
+}; //Mode660BestGrayK
 #endif // APDK_AUTODUPLEX
 
 #ifdef APDK_PROTO
