@@ -36,10 +36,10 @@
 
 APDK_BEGIN_NAMESPACE
 
-extern unsigned long ulMapCONQUEST_CMYK[ 9 * 9 * 9 ];
-extern unsigned long ulMapCONQUEST_ClMlxx[ 9 * 9 * 9 ];
-extern unsigned long ulMapVOLTAIRE_CCM_KCMY[ 9 * 9 * 9 ];
-extern unsigned long ulMapVOLTAIRE_CCM_K[ 9 * 9 * 9 ];
+extern uint32_t ulMapCONQUEST_CMYK[ 9 * 9 * 9 ];
+extern uint32_t ulMapCONQUEST_ClMlxx[ 9 * 9 * 9 ];
+extern uint32_t ulMapVOLTAIRE_CCM_KCMY[ 9 * 9 * 9 ];
+extern uint32_t ulMapVOLTAIRE_CCM_K[ 9 * 9 * 9 ];
 
 //
 // ** DJ6xxPhoto:Printer CLASS **
@@ -93,6 +93,15 @@ Mode690DraftGrayK::Mode690DraftGrayK()
    theQuality = qualityDraft;
    pmQuality = QUALITY_DRAFT;
 }
+
+Mode690BestGrayK::Mode690BestGrayK()
+: GrayMode(ulMapVOLTAIRE_CCM_K)
+{
+   theQuality = qualityPresentation;
+   pmQuality = QUALITY_BEST;
+   BaseResX = BaseResY = 600;
+   ResolutionX[0] = ResolutionY[0] = 600;
+}
 #endif // APDK_AUTODUPLEX
 
 DJ6xxPhoto::DJ6xxPhoto(SystemServices* pSS, BOOL proto)
@@ -116,7 +125,8 @@ DJ6xxPhoto::DJ6xxPhoto(SystemServices* pSS, BOOL proto)
 #ifdef APDK_AUTODUPLEX
     pMode[SPECIALMODE_INDEX+1] = new Mode690DraftGrayK(); 
     pMode[SPECIALMODE_INDEX+2] = new Mode690DraftColor();
-    ModeCount=5;
+    pMode[SPECIALMODE_INDEX+3] = new Mode690BestGrayK();
+    ModeCount=6;
 #else
     ModeCount = 3;
 #endif
@@ -149,6 +159,14 @@ DRIVER_ERROR Header690::Send()
     err = ConfigureRasterData();
     ERRCHECK;
 
+    if (ResolutionY[0] == 600)
+    {
+        char uom[10];
+        sprintf(uom,"%c%c%c%d%c",ESC,'&','u',thePrintMode->ResolutionY[K],'D');
+        err=thePrinter->Send((const BYTE*)uom, 7 );
+        ERRCHECK;
+    }
+
     err=Graphics();     // start raster graphics and set compression mode
 
 return err;
