@@ -90,6 +90,12 @@ class Mode690DraftColor : public PrintMode
 public:
     Mode690DraftColor();
 }; //Mode690DraftColor
+
+class Mode690BestGrayK : public GrayMode
+{
+public:
+    Mode690BestGrayK();
+}; //Mode690BestGrayK
 #endif // APDK_AUTODUPLEX
 
 #ifdef APDK_PROTO
