@@ -48,10 +48,10 @@ APDK_END_NAMESPACE              // must be here for non-test harness case
 
 APDK_BEGIN_NAMESPACE
 
-extern unsigned long ulMapVOLTAIRE_CCM_K[ 9 * 9 * 9 ];
-extern unsigned long ulMapPhobosPlainNormal[ 9 * 9 * 9 ];
-extern unsigned long ulMapVENICE_HB_KCMY[ 9 * 9 * 9 ];
-extern unsigned long ulMapPhobosDraft[ 9 * 9 * 9 ];
+extern uint32_t ulMapVOLTAIRE_CCM_K[ 9 * 9 * 9 ];
+extern uint32_t ulMapPhobosPlainNormal[ 9 * 9 * 9 ];
+extern uint32_t ulMapVENICE_HB_KCMY[ 9 * 9 * 9 ];
+extern uint32_t ulMapPhobosDraft[ 9 * 9 * 9 ];
 
 PhobosMode1::PhobosMode1()
 : PrintMode(ulMapPhobosPlainNormal)
@@ -64,7 +64,8 @@ PhobosMode1::PhobosMode1()
     for (int i=1; i < 4; i++)
         ColorDepth[i]=2;    // 300x300x2 CMY
 
-    ResolutionX[K]=ResolutionY[K]=600;
+    ResolutionX[K] =
+	ResolutionY[K] = 600;
 
     MixedRes = TRUE;
 
@@ -90,7 +91,7 @@ PhobosMode2::PhobosMode2()
     ColorDepth[K]=1;  // 600x600x1 K
 
     for (i=1; i < 4; i++)
-        ColorDepth[i]=2;    // 300x300x2 CMY
+        ColorDepth[i]=2;    // 600x600x2 CMY
 
     for (i=0; i < 4; i++)
         ResolutionX[i]=ResolutionY[i]=600;
@@ -98,7 +99,7 @@ PhobosMode2::PhobosMode2()
     BaseResX = BaseResY = 600;
     MixedRes = FALSE;
 
-    medium = mediaGlossy;
+    medium     = mediaGlossy;
     theQuality = qualityPresentation;
 
 #ifdef APDK_PROTO
@@ -115,10 +116,8 @@ PhobosMode2::PhobosMode2()
     dyeCount = 3;
     CompatiblePens[0] = COLOR_PEN;
 
-//     strcpy(ModeName, "Photo");
-
-     pmQuality = QUALITY_BEST;
-     pmMediaType = MEDIA_PHOTO;
+    pmQuality   = QUALITY_BEST;
+	pmMediaType = MEDIA_PHOTO;
 }
 
 PhobosMode3::PhobosMode3()
@@ -129,9 +128,7 @@ PhobosMode3::PhobosMode3()
     dyeCount = 3;
     CompatiblePens[0] = COLOR_PEN;
     theQuality = qualityDraft;
-//    strcpy(ModeName,"Draft");
-
-    pmQuality = QUALITY_DRAFT;
+    pmQuality  = QUALITY_DRAFT;
 }
 
 // Moved this mode to the Venice base class (8xx). des
