@@ -51,11 +51,11 @@ APDK_END_NAMESPACE
 
 APDK_BEGIN_NAMESPACE
 
-extern unsigned long ulMapVENICE_KCMY[ 9 * 9 * 9 ];
-extern unsigned long ulMapVOLTAIRE_CCM_K[ 9 * 9 * 9 ];
-extern unsigned long ulMapVENICE_HB_KCMY[ 9 * 9 * 9 ];
-extern unsigned long ulMapVENICE_Binary_KCMY[ 9 * 9 * 9 ];
-extern unsigned long ulMapGRAY_K_6x6x1[9 * 9 * 9];
+extern uint32_t ulMapVENICE_KCMY[ 9 * 9 * 9 ];
+extern uint32_t ulMapVOLTAIRE_CCM_K[ 9 * 9 * 9 ];
+extern uint32_t ulMapVENICE_HB_KCMY[ 9 * 9 * 9 ];
+extern uint32_t ulMapVENICE_Binary_KCMY[ 9 * 9 * 9 ];
+extern uint32_t ulMapGRAY_K_6x6x1[9 * 9 * 9];
 
 
 VeniceMode1::VeniceMode1()    // Normal Color
@@ -102,7 +102,7 @@ VeniceMode2::VeniceMode2()    // Photo
     BaseResX = BaseResY = 600;
     MixedRes = FALSE;
 
-    medium = mediaGlossy;
+    medium     = mediaGlossy;
     theQuality = qualityPresentation;
 
 #ifdef APDK_PROTO
@@ -118,7 +118,7 @@ VeniceMode2::VeniceMode2()    // Photo
 
 //     strcpy(ModeName, "Photo");
 
-     pmQuality = QUALITY_BEST;
+     pmQuality   = QUALITY_BEST;
      pmMediaType = MEDIA_PHOTO;
 }
 
@@ -226,6 +226,10 @@ DRIVER_ERROR Header895::StartSend()
     err=Modes();            // Set media source, type, size and quality modes.
     ERRCHECK;
 
+//  Now send media pre-load command
+    err = thePrinter->Send ((const BYTE *) "\033&l-2H", 6);   
+    ERRCHECK;
+
     char uom[10];
     sprintf(uom,"%c%c%c%d%c",ESC,'&','u',thePrintContext->EffectiveResolutionY(),'D');
     err=thePrinter->Send((const BYTE*)uom, strlen (uom));
@@ -355,7 +359,7 @@ DRIVER_ERROR DJ8xx::VerifyPenInfo()
 DRIVER_ERROR DJ8xx::ParsePenInfo(PEN_TYPE& ePen, BOOL QueryPrinter)
 {
     char* str;
-    DRIVER_ERROR err = SetPenInfo(str, QueryPrinter);
+    DRIVER_ERROR err = SetPenInfo (str, QueryPrinter);
     ERRCHECK;
 
 	if (*str != '$')
@@ -368,7 +372,13 @@ DRIVER_ERROR DJ8xx::ParsePenInfo(PEN_TYPE& ePen, BOOL QueryPrinter)
     // check pen1, assume it is black, pen2 is color
     switch (str[1])
     {
-        case 'H': temp_pen1 = BLACK_PEN; break; // (H)obbes black
+        case 'H': // (H)obbes
+		case 'L': // (L)inus
+		case 'Z': // (Z)orro
+		{
+			temp_pen1 = BLACK_PEN;
+			break;
+		}
         case 'X': return UNSUPPORTED_PEN;
         default:  temp_pen1 = NO_PEN; break;
     }
@@ -415,78 +425,6 @@ Compressor* DJ8xx::CreateCompressor(unsigned int RasterSize)
     return new Mode2(pSS,RasterSize);
 }
 
-///////////////////////////////////////////////////////////////////
-Mode2::Mode2(SystemServices* pSys, unsigned int RasterSize)
-    : Compressor(pSys,RasterSize,FALSE)
-{
-    compressBuf = (BYTE*)pSS->AllocMem(RasterSize);
-    if (compressBuf == NULL)
-    {
-        constructor_error=ALLOCMEM_ERROR;
-    }
-
-}
-
-Mode2::~Mode2()
-{ }
-
-BOOL Mode2::Process(BYTE* input, unsigned int size)
-// mode 2 compression code from Kevin Hudson
-{
-    BYTE* pDst = compressBuf;
-    int ndstcount = 0;
-
-    if (input==NULL)    // flushing pipeline
-    {
-        compressedsize=0;
-        iRastersReady=0;
-        return FALSE;
-    }
-
-    for (unsigned int ni = 0; ni < size;)
-    {
-        if ( ni + 1 < size && input[ ni ] == input[ ni + 1 ] )
-        {
-            unsigned int nrepeatcount;
-            for ( ni += 2, nrepeatcount = 1; ni < size && nrepeatcount < 127; ++ni, ++nrepeatcount )
-            {
-                if ( input[ ni ] != input[ ni - 1 ] )
-                {
-                    break;
-                }
-            }
-            int tmprepeat = 0 - nrepeatcount;
-            BYTE trunc = (BYTE) tmprepeat;
-            pDst[ ndstcount++ ] = trunc;
-            pDst[ ndstcount++ ] = input[ ni - 1 ];
-        }
-        else
-        {
-            int nliteralcount;
-            int nfirst = ni;
-            for ( ++ni, nliteralcount = 0; ni < size && nliteralcount < 127; ++ni, ++nliteralcount )
-            {
-                if ( input[ ni ] == input[ ni - 1 ] )
-                {
-                    --ni;
-                    --nliteralcount;
-                    break;
-                }
-            }
-            pDst[ ndstcount++ ] = (BYTE) nliteralcount;
-            for ( int nj = 0; nj <= nliteralcount; ++nj )
-            {
-                pDst[ ndstcount++ ] = input[ nfirst++ ];
-            }
-        }
-    }
-
-    size = ndstcount;
-    compressedsize = size;
-    iRastersReady = 1;
-    return TRUE;
-}
-
 BOOL DJ8xx::UseGUIMode(PrintMode* pPrintMode)
 {
     return (!pPrintMode->bFontCapable);
