@@ -31,13 +31,15 @@
 
 #include "config.h"
 
+#include "global_types.h"
+
 APDK_BEGIN_NAMESPACE
 
 #if defined(APDK_DJ9xx)
 
 // 600x600x1, K    - Plain, Normal, Grey
 
-unsigned long ulMapGRAY_K_6x6x1[] =
+uint32_t ulMapGRAY_K_6x6x1[] =
 {
     255UL, 238UL, 218UL, 204UL, 189UL, 181UL, 171UL, 161UL, 154UL,
     178UL, 168UL, 161UL, 153UL, 148UL, 141UL, 136UL, 130UL, 127UL,
@@ -123,7 +125,7 @@ unsigned long ulMapGRAY_K_6x6x1[] =
 };
 #endif
 
-unsigned long ulMapBROADWAY_KCMY[ 9*9*9 ]=
+uint32_t ulMapBROADWAY_KCMY[ 9*9*9 ]=
 {
 976236799UL,  280493625UL,  398065443UL,  380960535UL,  347078160UL,  363724298UL,
  498335489UL,  313130752UL,   10092288UL, 4279031100UL,  774831941UL,  562954021UL,
