@@ -35,9 +35,9 @@
 #include "io_defs.h"
 #include "dj8xx.h"
 #include "dj9xx.h"
+#include "resources.h"
 
 #ifdef APDK_PROTO
-#include "resources.h"
 extern int argProprietaryImaging;
 extern BOOL argPhotoTray;
 #else
@@ -49,11 +49,11 @@ APDK_END_NAMESPACE
 
 APDK_BEGIN_NAMESPACE
 
-extern unsigned long ulMapBROADWAY_KCMY[ 9 * 9 * 9 ];
-extern unsigned long ulMapBROADWAY_Gossimer_Normal_KCMY[ 9 * 9 * 9 ];
-extern unsigned long ulMapVOLTAIRE_CCM_K[ 9 * 9 * 9 ];
-extern unsigned long ulMapGRAY_K_6x6x1[9 * 9 * 9];
-extern unsigned long ulMapBROADWAY_Draft_KCMY[9 * 9 * 9];
+extern uint32_t ulMapBROADWAY_KCMY[ 9 * 9 * 9 ];
+extern uint32_t ulMapBROADWAY_Gossimer_Normal_KCMY[ 9 * 9 * 9 ];
+extern uint32_t ulMapVOLTAIRE_CCM_K[ 9 * 9 * 9 ];
+extern uint32_t ulMapGRAY_K_6x6x1[9 * 9 * 9];
+extern uint32_t ulMapBROADWAY_Draft_KCMY[9 * 9 * 9];
 
 DJ9xx::DJ9xx(SystemServices* pSS, BOOL proto)
 : Printer(pSS,NUM_DJ6XX_FONTS,proto)
@@ -80,7 +80,9 @@ DJ9xx::DJ9xx(SystemServices* pSS, BOOL proto)
     pMode[GRAYMODE_INDEX]      = new BroadwayMode3 ();   // Draft Grayscale K
     pMode[SPECIALMODE_INDEX+1] = new BroadwayMode4 ();   // Normal Grayscale K
     pMode[SPECIALMODE_INDEX+2] = new BroadwayMode5 ();   // Draft Color
-    ModeCount = 5;
+    pMode[SPECIALMODE_INDEX+3] = new BroadwayModePres();       // Best Color
+    pMode[SPECIALMODE_INDEX+4] = new BroadwayModePhotoPres();  // HiRes
+    ModeCount=7;
 #else
     pMode[GRAYMODE_INDEX]    = new GrayMode (ulMapVOLTAIRE_CCM_K);
     ModeCount=3;
@@ -155,8 +157,8 @@ BroadwayMode2::BroadwayMode2()    // Photo
     bDuplexCapable = FALSE;
 #endif
 
-    pmQuality=QUALITY_BEST;
-    pmMediaType=MEDIA_PHOTO;
+    pmQuality   = QUALITY_BEST;
+    pmMediaType = MEDIA_PHOTO;
 }
 
 #ifdef APDK_AUTODUPLEX
@@ -191,6 +193,61 @@ BroadwayMode5::BroadwayMode5()    // Draft Color
     pmQuality = QUALITY_DRAFT;
     theQuality = qualityDraft;
 }
+
+// 2001.06.14 mrb: Added Presentation Mode: 600x600x2 for color,
+//                                          600x600x1 for b/w
+BroadwayModePres::BroadwayModePres() : PrintMode(ulMapBROADWAY_KCMY)
+// 600x600x1 K
+// 600x600x2 CMY
+{
+    ColorDepth[K]=1;
+    
+    ColorDepth[C]=2;
+    ColorDepth[M]=2;
+    ColorDepth[Y]=2;
+
+    ResolutionX[K]=ResolutionY[K]=600;
+    ResolutionX[C]=ResolutionY[C]=600;
+    ResolutionX[M]=ResolutionY[M]=600;
+    ResolutionX[Y]=ResolutionY[Y]=600;
+
+    BaseResX = BaseResY = 600;
+    theQuality = qualityPresentation;
+
+    // 2001.07.09 mrb: Added for presentation mode of DJ970
+    ColorFEDTable = (BYTE*) HT600x600x4_Pres970_open;
+
+    bDuplexCapable = TRUE;
+    pmQuality   = QUALITY_BEST;
+}
+
+// 2001.06.14 mrb: Added Presentation Photo Mode: 1200x1200x1 for color.
+BroadwayModePhotoPres::BroadwayModePhotoPres() 
+: PrintMode(ulMapBROADWAY_Gossimer_Normal_KCMY) 
+// 1200x1200x1 CMY
+{
+    ColorDepth[K]=1;
+    ColorDepth[C]=1;
+    ColorDepth[M]=1;
+    ColorDepth[Y]=1;
+
+    ResolutionX[K]=ResolutionY[K]=1200;
+    ResolutionX[C]=ResolutionY[C]=1200;
+    ResolutionX[M]=ResolutionY[M]=1200;
+    ResolutionX[Y]=ResolutionY[Y]=1200;
+
+    BaseResX = BaseResY = 1200;
+
+    medium = mediaGlossy;
+    theQuality = qualityPresentation;
+
+    // 2001.07.09 mrb: Added for presentation mode of DJ970
+    ColorFEDTable = (BYTE*) HT1200x1200x1_PhotoPres970_open;
+
+    bFontCapable=FALSE;
+    pmQuality   = QUALITY_HIGHRES_PHOTO;
+    pmMediaType = MEDIA_PHOTO;
+}
 #endif  // APDK_AUTODUPLEX
 
 BOOL DJ9xx::UseGUIMode(PrintMode* pPrintMode)
@@ -300,6 +357,11 @@ BYTE DJ9xx::PhotoTrayStatus
 
     BYTE bDevIDBuff[DevIDBuffSize];
 
+    if (!IOMode.bDevID)
+    {
+        bQueryPrinter = FALSE;
+    }
+
     err=pSS->GetDeviceID(bDevIDBuff, DevIDBuffSize, bQueryPrinter);
     if (err!=NO_ERROR)
     {
@@ -550,7 +612,11 @@ DRIVER_ERROR DJ9xx::ParsePenInfo(PEN_TYPE& ePen, BOOL QueryPrinter)
     // check pen1, assume it is black, pen2 is color
     switch (str[1])
     {
-        case 'H': temp_pen1 = BLACK_PEN; break; // (H)obbes black
+        case 'H':		// Hobbes
+		case 'L':		// Linus
+		case 'Z':		// Zorro
+			temp_pen1 = BLACK_PEN;
+			break;
         case 'X': return UNSUPPORTED_PEN;
         default:  temp_pen1 = NO_PEN; break;
     }
