@@ -108,6 +108,21 @@ class BroadwayMode5 : public PrintMode
 public:
     BroadwayMode5 ();
 };
+
+class BroadwayModePres : public PrintMode
+{
+public:
+    BroadwayModePres();
+
+};
+
+class BroadwayModePhotoPres : public PrintMode
+{
+public:
+    BroadwayModePhotoPres();
+
+};
+
 #endif // APDK_AUTODUPLEX
 
 
