@@ -45,9 +45,10 @@ APDK_BEGIN_NAMESPACE
 #define OUR_PJL_JOBNAME "_PJL_pjl_PJL_pjl_" // this can be anything we want it to be
 #define DRIVERWARE_JOBNAME  "NEWDRIVERWARE" // don't change this - it is defined in firmware!
 
-extern unsigned long ulMapVOLTAIRE_CCM_K[ 9 * 9 * 9 ];
+extern uint32_t ulMapVOLTAIRE_CCM_K[ 9 * 9 * 9 ];
 
 const char GrayscaleSeq[]= {ESC, '*', 'o', '5', 'W', 0x0B, 0x01, 0x00, 0x00, 0x02};
+extern BYTE EscAmplCopy(BYTE *dest, int num, char end);
 
 
 DJ9xxVIP::DJ9xxVIP
@@ -71,10 +72,10 @@ DJ9xxVIP::DJ9xxVIP
 
     PCL3acceptsDriverware = IsPCL3DriverwareAvailable();
 
-    pMode[GRAYMODE_INDEX] = new GrayModeAladdin(ulMapVOLTAIRE_CCM_K,PCL3acceptsDriverware);  // Grayscale K
-    pMode[DEFAULTMODE_INDEX] = new AladdinMode();           // Normal Color
-    pMode[SPECIALMODE_INDEX] = new AladdinCMYGrayMode();    // Normal Grayscale CMY
-    ModeCount = 3;
+    ModeCount = 0;
+    pMode[ModeCount++] = new GrayModeAladdin(ulMapVOLTAIRE_CCM_K,PCL3acceptsDriverware);  // Grayscale K
+    pMode[ModeCount++] = new AladdinMode();           // Automatic Color
+    pMode[ModeCount++] = new AladdinCMYGrayMode();    // Automatic Grayscale CMY
 
 #ifdef APDK_AUTODUPLEX
 
@@ -84,17 +85,17 @@ DJ9xxVIP::DJ9xxVIP
  */
 
     bDuplexCapable = TRUE;
-    pMode[SPECIALMODE_INDEX+1] = new AladdinKGrayMode ();        // Normal Grayscale K
-    pMode[SPECIALMODE_INDEX+2] = new Aladdin2400Mode ();         // HiRes
-    pMode[SPECIALMODE_INDEX+3] = new AladdinDraftMode ();        // Draft Color
-    ModeCount = 6;
+    pMode[ModeCount++] = new AladdinKGrayMode ();        // Normal Grayscale K
+    pMode[ModeCount++] = new Aladdin2400Mode ();         // HiRes
+    pMode[ModeCount++] = new AladdinDraftMode ();        // Draft Color
 #endif
+    pMode[ModeCount++] = new AladdinBestMode ();        // Photo Best
 
 }
 
 GrayModeAladdin::GrayModeAladdin
 (
-    unsigned long *map,
+    uint32_t *map,
     BOOL PCL3OK
 ) :
     GrayMode(map)
@@ -231,6 +232,33 @@ AladdinDraftMode::AladdinDraftMode () : PrintMode (NULL)
 
 #endif  // APDK_AUTODUPLEX
 
+/*
+ *  Some VIP printers do not have Media Sensing device. To enable
+ *  selection of Photo/Best mode for these printers, use this mode.
+ */
+
+AladdinBestMode::AladdinBestMode () : PrintMode (NULL)
+{
+    BaseResX = BaseResY = ResolutionX[0] = ResolutionY[0] = VIP_BASE_RES;
+
+	bFontCapable = FALSE;
+
+#ifdef  APDK_AUTODUPLEX
+	bDuplexCapable = TRUE;
+#endif
+
+#if defined(APDK_VIP_COLORFILTERING)
+    Config.bErnie = TRUE;
+#endif
+
+   Config.bColorImage = FALSE;
+
+	medium      = mediaGlossy;
+	theQuality  = qualityPresentation;
+	pmQuality   = QUALITY_BEST;
+    pmMediaType = MEDIA_PHOTO;
+} // AladdinBestMode
+
 BOOL DJ9xxVIP::UseGUIMode
 (
     PrintMode* pPrintMode
@@ -246,7 +274,8 @@ BOOL DJ9xxVIP::UseGUIMode
     }
 #endif
 #if defined(APDK_FONTS_NEEDED)
-    return ((!pPrintMode->bFontCapable) && (!PCL3acceptsDriverware));
+//    return ((!pPrintMode->bFontCapable) && (!PCL3acceptsDriverware));
+    return (!pPrintMode->bFontCapable);
 #else
     return TRUE;
 #endif
@@ -315,7 +344,9 @@ Header* DJ9xxVIP::SelectHeader(PrintContext* pc)
 
 HeaderAladdin::HeaderAladdin(Printer* p,PrintContext* pc)
     : Header(p,pc)
-{ }
+{
+    SetMediaSource(pc->GetMediaSource());
+}
 
 
 DRIVER_ERROR HeaderAladdin::ConfigureRasterData()
@@ -476,6 +507,7 @@ DRIVER_ERROR HeaderAladdin::Send()
     sprintf(uom,"%c%c%c%d%c",ESC,'*','r', width,'S');
     err = thePrinter->Send((const BYTE*)uom, 4 + digits );
     ERRCHECK;
+
     ////////////////////////////////////////////////////////////////////////////////////
     float   fXOverSpray = 0.0;
     float   fYOverSpray = 0.0;
@@ -525,6 +557,18 @@ DRIVER_ERROR HeaderAladdin::Send()
     err = thePrinter->Send((const BYTE*)grafStart, sizeof(grafStart) );
     ERRCHECK;
 
+    if (!thePrinter->UseGUIMode (thePrintContext->CurrentMode) &&
+        (thePrintContext->PhysicalPageSizeX ()) < 8.0)
+    {
+
+        BYTE    blankRow[40];
+        memset (blankRow, 0xFF, 40);
+        strcpy ((char *) blankRow, "\033*p0Y\033*b23W");
+        blankRow[11] = 18;   // ce, 7f
+        blankRow[30] = 0xCE; blankRow[31] = 0x7F;
+        err = thePrinter->Send ((const BYTE *) blankRow, 34);
+    }
+    
     return err;
 } //Send
 
@@ -559,9 +603,18 @@ DRIVER_ERROR HeaderAladdin::StartSend()
     err = Modes ();            // Set media source, type, size and quality modes.
     ERRCHECK;
 
+//  Now send media pre-load command
+    err = thePrinter->Send ((const BYTE *) "\033&l-2H", 6);   
+    ERRCHECK;
+
     if (!thePrinter->UseGUIMode(thePrintContext->CurrentMode))
     {
         err = Margins();          // set margins
+
+/*        if (thePrintContext->PhysicalPageSizeX () < 8.0)
+        {
+            err = thePrinter->Send ((const BYTE *) "\033&l2A", 5);
+        }*/
     }
 
 // special GUI mode top margin set
@@ -574,6 +627,12 @@ DRIVER_ERROR HeaderAladdin::StartSend()
     return err;
 } //StartSend
 
+/* This could replace Header::SetMediaSource in header.cpp. des 8/5/02 */
+void HeaderAladdin::SetMediaSource(MediaSource msource)
+// Sets value of PCL::mediasource and associated counter msrccount
+{
+    msrccount=EscAmplCopy((BYTE*)mediasource,msource,'H');
+}
 
 void AsciiHexToBinary(BYTE* dest, char* src, int count)
 {
@@ -741,9 +800,24 @@ DRIVER_ERROR DJ9xxVIP::ParsePenInfo(PEN_TYPE& ePen, BOOL QueryPrinter)
     int num_pens = 0;
     PEN_TYPE temp_pen1 = NO_PEN;
     BYTE penInfoBits[4];
-    DRIVER_ERROR err = SetPenInfo(str, QueryPrinter);
+
+/*
+ *  First check if this printer's firmware version is one I know about. Currently
+ *  I know upto S:04. I can't guess if the pen info nibbles have shifted in the
+ *  new version. Can't tell the user about missing pens.
+ */
+
+    if ((pSS->GetVIPVersion ()) > 5)
+    {
+        ePen = BOTH_PENS;
+        return NO_ERROR;
+    }
+
+    DRIVER_ERROR err = SetPenInfo (str, QueryPrinter);
     ERRCHECK;
 
+	iNumMissingPens = 0;
+
     // the first byte indicates how many pens are supported
     if ((str[0] >= '0') && (str[0] <= '9'))
     {
@@ -783,6 +857,7 @@ DRIVER_ERROR DJ9xxVIP::ParsePenInfo(PEN_TYPE& ePen, BOOL QueryPrinter)
         else if (penInfoBits[0] == 0xc0)
         {   // missing pen
             temp_pen1 = NO_PEN;
+			iNumMissingPens = 1;
         }
         else
         {
@@ -807,6 +882,7 @@ DRIVER_ERROR DJ9xxVIP::ParsePenInfo(PEN_TYPE& ePen, BOOL QueryPrinter)
         else if (penInfoBits[0] == 0xc0)
         {   // missing pen
             ePen = temp_pen1;
+			iNumMissingPens = 1;
         }
         else
         {
@@ -886,7 +962,10 @@ DRIVER_ERROR DJ9xxVIP::ParsePenInfo(PEN_TYPE& ePen, BOOL QueryPrinter)
         switch (penColor)
         {
             case 0:
+			{
+				iNumMissingPens++;
                 break;
+			}
             case 1:
                 ePen = BLACK_PEN;
                 break;
@@ -1015,10 +1094,10 @@ BOOL DJ9xxVIP::IsPCL3DriverwareAvailable()
     for (i=0; i<maxWaitTries; i++)
     {
         if (pSS->GetDeviceID(devIDBuff, DevIDBuffSize, TRUE) != NO_ERROR)    goto cleanup;
-        if ( (pStr=strstr((const char*)devIDBuff+2,";J:")) )
+        if ( (pStr=(char *)strstr((const char*)devIDBuff+2,";J:")) )
         {
             pStr += 3;
-            if ( (pEnd=strstr((const char*)pStr,";")) )
+            if ( (pEnd=(char *)strstr((const char*)pStr,";")) )
             {
                 *pEnd = '\0';
                 while (pEnd > pStr) // take out trailing spaces in JobName before compare
@@ -1069,10 +1148,10 @@ BOOL DJ9xxVIP::IsPCL3DriverwareAvailable()
     for (i=0; i<maxWaitTries; i++)
     {
         if (pSS->GetDeviceID(devIDBuff, DevIDBuffSize, TRUE) != NO_ERROR)    goto cleanup;
-        if ( (pStr=strstr((const char*)devIDBuff+2,";J:")) )
+        if ( (pStr=(char *)strstr((const char*)devIDBuff+2,";J:")) )
         {
             pStr += 3;
-            if ( (pEnd=strstr((const char*)pStr,";")) )
+            if ( (pEnd=(char *)strstr((const char*)pStr,";")) )
             {
                 *pEnd = '\0';
                 // firmware may have garbage in remainder of JobName buffer - truncate
@@ -1118,25 +1197,27 @@ DISPLAY_STATUS DJ9xxVIP::ParseError(BYTE status_reg)
     DRIVER_ERROR err = NO_ERROR;
     BYTE DevIDBuffer[DevIDBuffSize];
     char *pStr;
+    int     iVersion = pSS->GetVIPVersion ();
 
-    if(IOMode.bDevID)
+    if(IOMode.bDevID && iVersion < 6)
     {
         // If a bi-di cable was plugged in and everything was OK, let's see if it's still
         // plugged in and everything is OK
-        err = pSS->GetDeviceID(DevIDBuffer, DevIDBuffSize, TRUE);
+        err = pSS->GetDeviceID (DevIDBuffer, DevIDBuffSize, TRUE);
         if(err != NO_ERROR)
         {
             // job was bi-di but now something's messed up, probably cable unplugged
             return DISPLAY_COMM_PROBLEM;
         }
 
-        if ( (pStr=strstr((const char*)DevIDBuffer+2,";S:")) == NULL )
+        if ( (pStr=(char *)strstr((const char*)DevIDBuffer+2,";S:")) == NULL )
         {
             return DISPLAY_COMM_PROBLEM;
         }
 
         // point to PrinterState
         BYTE b1,b2;
+
         pStr+=5;   // 3 for ";S:", 2 for version -- point to first byte of "printer state"
         b1=*pStr;
 
@@ -1145,14 +1226,18 @@ DISPLAY_STATUS DJ9xxVIP::ParseError(BYTE status_reg)
             return DISPLAY_TOP_COVER_OPEN;
         }
 
-		if ((pSS->GetVIPVersion ()) < 3)
+		if (iVersion < 3)
 		{
 			pStr += 12;     // point to "feature state"
 		}
-		else
+		else if (iVersion < 5)
 		{
 			pStr += 14;
 		}
+        else
+        {
+            pStr += 18;
+        }
 
         b1=*pStr++;
         b2=*pStr++;
@@ -1174,9 +1259,30 @@ DISPLAY_STATUS DJ9xxVIP::ParseError(BYTE status_reg)
 			return DISPLAY_PHOTOTRAY_MISMATCH;
 		}
 
+//      Paper Jam or Paper Stall
+
+        if ((b1 == '1' && b2 == '0') ||        // Paper Jam
+            (b1 == '0' && (b2 == 'e' || b2 == 'E')))
+        {
+            return DISPLAY_PAPER_JAMMED;
+        }
+
+//      Carriage Stall
+
+        if (b1 == '0' && (b2 == 'F' || b2 == 'f'))
+        {
+            return DISPLAY_ERROR_TRAP;
+        }
+
+        if ((b1=='0') && (b2=='5'))     // 05 = CNCL state
+        {
+            DBG1("Printing Canceled [from Encoded DevID]\n");
+            return DISPLAY_PRINTING_CANCELED;
+        }
+
         // VerifyPenInfo will handle prompting the user
         // if this is a problem
-        err = VerifyPenInfo();
+        err = VerifyPenInfo ();
 
         if(err != NO_ERROR)
         {
@@ -1208,11 +1314,17 @@ DISPLAY_STATUS DJ9xxVIP::ParseError(BYTE status_reg)
             DBG1("Jammed [from status byte]\n");
             return DISPLAY_PAPER_JAMMED;
         }
+/*
+ *      Do not process this. Malibu printers set the NFAULT bit low when a pen is
+ *      missing, eventhough they support reserve mode printing. This causes us to
+ *      report ERROR_TRAP message. Consequence is that we may not catch carriage
+ *      stall, but should eventually result in time out.
 		if (DEVICE_IO_TRAP(status_reg))
 		{
             DBG1("Jammed or trapped [from status byte]\n");
             return DISPLAY_ERROR_TRAP;
 		}
+ */
     }
 
     // don't know what the problem is-
@@ -1316,7 +1428,7 @@ void TErnieFilter::Flush()
 
 #endif //APDK_VIP_COLORFILTERING
 
-inline unsigned long Mode10::get3Pixel
+inline uint32_t Mode10::get3Pixel
 (
     BYTE* pixAddress,
     int pixelOffset
@@ -1339,7 +1451,7 @@ void Mode10::put3Pixel
 (
     BYTE* pixAddress,
     int pixelOffset,
-    unsigned long pixel
+    uint32_t pixel
 )
 {
     pixAddress += ((pixelOffset << 1) + pixelOffset);     //pixAddress += pixelOffset * 3;
@@ -1355,8 +1467,8 @@ void Mode10::put3Pixel
 
 unsigned short Mode10::ShortDelta
 (
-    unsigned long lastPixel,
-    unsigned long lastUpperPixel
+    uint32_t lastPixel,
+    uint32_t lastUpperPixel
 )
 {
     int dr,dg,db;
@@ -1417,9 +1529,9 @@ This function compresses a single row per call.
     unsigned int lastPixel = (rowWidthInBytes / BYTES_PER_PIXEL) - 1;
 
     // Setup sentinal value to replace last pixel of curRow. Simplifies future end condition checking.
-    unsigned long realLastPixel = getPixel(curRowPtr, lastPixel);
+    uint32_t realLastPixel = getPixel(curRowPtr, lastPixel);
 
-    unsigned long newLastPixel = realLastPixel;
+    uint32_t newLastPixel = realLastPixel;
     while ((getPixel(curRowPtr, lastPixel-1) == newLastPixel) ||
             (getPixel(seedRowPtr, lastPixel) == newLastPixel))
     {
@@ -1469,7 +1581,7 @@ This function compresses a single row per call.
             ASSERT(curPixel < lastPixel);
 
             replacementCount = curPixel;
-            unsigned long RLERun = getPixel(curRowPtr, curPixel);
+            uint32_t RLERun = getPixel(curRowPtr, curPixel);
 
             curPixel++; // Adjust for next pixel.
             while (RLERun == getPixel(curRowPtr, curPixel)) // RLE
@@ -1521,7 +1633,7 @@ This function compresses a single row per call.
 
             if (0 == replacementCount) // no RLE so it's a literal by default.
             {
-                unsigned long tempPixel = getPixel(curRowPtr, curPixel);
+                uint32_t tempPixel = getPixel(curRowPtr, curPixel);
 
                 ASSERT(tempPixel != getPixel(curRowPtr, curPixel+1)); // not RLE
                 ASSERT(tempPixel != getPixel(seedRowPtr, curPixel)); // not seedrow copy
@@ -1551,8 +1663,8 @@ This function compresses a single row per call.
                 }
 
                 replacementCount = curPixel;
-                unsigned long cachePixel;
-                unsigned long nextPixel = getPixel(curRowPtr, curPixel+1);
+                uint32_t cachePixel;
+                uint32_t nextPixel = getPixel(curRowPtr, curPixel+1);
                 do
                 {
                     if (++curPixel == lastPixel)
@@ -1617,7 +1729,7 @@ This function compresses a single row per call.
                 }
                 else
                 {
-                    unsigned long uncompressedPixel = getPixel(curRowPtr, curPixel-replacementCount);
+                    uint32_t uncompressedPixel = getPixel(curRowPtr, curPixel-replacementCount);
 
                     uncompressedPixel >>= 1; // Lose the lsb of blue and zero out the msb of the 3 bytes.
 
@@ -1666,7 +1778,7 @@ This function compresses a single row per call.
                 }
                 else
                 {
-                    unsigned long uncompressedPixel = getPixel(curRowPtr, curPixel - replacementCount);
+                    uint32_t uncompressedPixel = getPixel(curRowPtr, curPixel - replacementCount);
 
                     uncompressedPixel >>= 1;
 
@@ -1700,13 +1812,18 @@ BYTE DJ9xxVIP::PhotoTrayStatus
 
     BYTE bDevIDBuff[DevIDBuffSize];
 
+    if (!IOMode.bDevID)
+    {
+        bQueryPrinter = FALSE;
+    }
+
     err = pSS->GetDeviceID(bDevIDBuff, DevIDBuffSize, bQueryPrinter);
     if (err!=NO_ERROR)
     {
         return 0;
     }
 
-    if ( (pStr=strstr((const char*)bDevIDBuff+2,";S:")) == NULL )
+    if ( (pStr=(char *)strstr((const char*)bDevIDBuff+2,";S:")) == NULL )
     {
         return 0;
     }
@@ -1773,13 +1890,27 @@ DRIVER_ERROR DJ9xxVIP::CheckInkLevel()
 
     BYTE bDevIDBuff[DevIDBuffSize];
 
-    err=pSS->GetDeviceID(bDevIDBuff, DevIDBuffSize, TRUE);
+    if (!IOMode.bDevID)
+    {
+        return NO_ERROR;
+    }
+
+/*
+ *  Check for unknown device id version.
+ */
+     
+    if ((pSS->GetVIPVersion ()) > 5)
+    {
+        return NO_ERROR;
+    }
+
+    err = pSS->GetDeviceID(bDevIDBuff, DevIDBuffSize, TRUE);
     if (err!=NO_ERROR)
     {
         return err;
     }
 
-    if ( (pStr=strstr((const char*)bDevIDBuff+2,";S:")) == NULL )
+    if ( (pStr=(char *)strstr((const char*)bDevIDBuff+2,";S:")) == NULL )
     {
         return SYSTEM_ERROR;
     }
@@ -1836,7 +1967,13 @@ DRIVER_ERROR DJ9xxVIP::CheckInkLevel()
             return WARN_LOW_INK_COLOR;
         }
     }
+
     pStr += 21;
+    if (pSS->GetVIPVersion () > 4)
+    {
+        pStr += 4;
+    }
+
     int     numPens = 0;
     if (*pStr > '0' && *pStr < '9')
     {
