@@ -67,6 +67,7 @@ public:
 protected:
     BOOL PCL3acceptsDriverware;
     virtual BYTE PhotoTrayStatus(BOOL bQueryPrinter);
+	int		iNumMissingPens;
 
 private:
     BOOL IsPCL3DriverwareAvailable();
@@ -83,7 +84,7 @@ public:
 class GrayModeAladdin : public GrayMode
 {
 public:
-    GrayModeAladdin (unsigned long *map, BOOL PCL3OK);
+    GrayModeAladdin (uint32_t *map, BOOL PCL3OK);
 }; //GrayModeAladdin
 
 class AladdinCMYGrayMode : public PrintMode
@@ -113,6 +114,11 @@ public:
 
 #endif // APDK_AUTODUPLEX
 
+class AladdinBestMode : public PrintMode
+{
+public:
+    AladdinBestMode ();
+};  // AladdinBestMode
 
 #ifdef APDK_HIGH_RES_MODES
     const int VIP_BASE_RES = 600;
@@ -224,7 +230,7 @@ public:
 private:
     Printer* thePrinter;
 
-    inline unsigned long get4Pixel(unsigned char *pixAddress, unsigned int bPrint = FALSE)
+    inline uint32_t get4Pixel(unsigned char *pixAddress, unsigned int bPrint = FALSE)
         {
             #ifdef APDK_LITTLE_ENDIAN
                 return (((unsigned int*)pixAddress)[0]) & kWhite;
@@ -234,7 +240,7 @@ private:
         }
 
 
-    inline unsigned long get4Pixel(unsigned char *pixAddress, int pixelOffset)
+    inline uint32_t get4Pixel(unsigned char *pixAddress, int pixelOffset)
         {
             #ifdef APDK_LITTLE_ENDIAN
                 return ((unsigned int*)pixAddress)[pixelOffset] & kWhite;
@@ -244,7 +250,7 @@ private:
         }
 
 
-    inline void put4Pixel(unsigned char *pixAddress, int pixelOffset, unsigned long pixel)
+    inline void put4Pixel(unsigned char *pixAddress, int pixelOffset, uint32_t pixel)
         {
             #ifdef APDK_LITTLE_ENDIAN
                 (((unsigned int*)pixAddress)[pixelOffset] = pixel & kWhite);
@@ -268,9 +274,9 @@ private:
     }
 
 
-    void put3Pixel(BYTE* pixAddress, int pixelOffset, unsigned long pixel);
-    inline unsigned long get3Pixel(BYTE* pixAddress, int pixelOffset);
-    unsigned short ShortDelta(unsigned long lastPixel, unsigned long lastUpperPixel);
+    void put3Pixel(BYTE* pixAddress, int pixelOffset, uint32_t pixel);
+    inline uint32_t get3Pixel(BYTE* pixAddress, int pixelOffset);
+    unsigned short ShortDelta(uint32_t lastPixel, uint32_t lastUpperPixel);
 
 
 }; //Mode10
