@@ -29,7 +29,7 @@
 \*****************************************************************************/
 
 
-#ifdef APDK_DJ9xxVIP
+#if defined(APDK_DJGENERICVIP) && defined (APDK_DJ9xxVIP)
 
 #include "header.h"
 #include "dj9xxvip.h"
@@ -136,6 +136,8 @@ BOOL DJGenericVIP::FullBleedCapable (PAPER_SIZE ps, float *xOverSpray, float *yO
                 *fTopOverSpray  = (float) 0.03;
             return TRUE;
         }
+        default:
+            break;
     }
 
     *xOverSpray = (float) 0.18;
@@ -208,9 +210,28 @@ DRIVER_ERROR DJGenericVIP::VerifyPenInfo ()
 
     ERRCHECK;
 
-    while (ePen == NO_PEN)
+/*
+ *	If one or more pens are not installed, check the device id for ReserveMode
+ *	capability for this printer. This info in in the flags nibble
+ *	;S:<XX><toplid><supplylic><duplexer><phototray><in-1><in-2><banner><flags>
+ *	flags : x1xx - reserve mode supported, x0xx - not supported
+ */
+
+    BYTE    sDevIdStr[DevIDBuffSize];
+    char    *pStr;
+	BOOL	bNeedAllPens = FALSE;
+
+    if (iNumMissingPens > 0 && ((pSS->GetDeviceID (sDevIdStr, DevIDBuffSize, FALSE)) == NO_ERROR))
     {
-		if (ePen == NO_PEN)
+        if ((pStr = strstr ((char *) sDevIdStr, ";S:")))
+        {
+			bNeedAllPens = !(*(pStr+12) & 0x04);
+        }
+	}
+
+    while (ePen == NO_PEN || (bNeedAllPens && iNumMissingPens > 0))
+    {
+		if (ePen == NO_PEN || iNumMissingPens > 0)
 		{
 			pSS->DisplayPrinterStatus (DISPLAY_NO_PENS);
 
@@ -260,4 +281,4 @@ void DJGenericVIP::AdjustModeSettings (BOOL bDoFullBleed, MEDIATYPE ReqMedia,
 } // AdjustModeSettings
 APDK_END_NAMESPACE
 
-#endif //APDK_DJ9xxVIP
+#endif // defined(APDK_DJGENERICVIP) && defined (APDK_DJ9xxVIP)
