@@ -46,17 +46,27 @@ Definitions for global variables, types, and #defines
 #include "models.h"
 #include "modes.h"
 
+
+
+#if APDK_AUTO_INCLUDE
+    #include "auto-include.h"
+#else
+    typedef unsigned long uint32_t;
+#endif
+
 // ** Defines
 
-#ifndef NOTHROW
-    #define NOTHROW (nothrow)
+#ifdef APDK_NOTHROW
+    #include <new>
+    //#define NOTHROW (std::nothrow)
+    #define new new(std::nothrow)
 #endif
 
 // Camera compiler warns about NULL at different locations each time.
 // So, force a definition here.
 
-#ifdef	NULL
-#undef NULL
+#ifdef NULL
+    #undef NULL
 #endif
 
 #ifndef NULL
@@ -73,7 +83,7 @@ typedef unsigned char BYTE;
 
 typedef unsigned short WORD;
 
-typedef unsigned long DWORD;
+typedef uint32_t DWORD;
 
 #ifndef LOWORD
     #define LOWORD(l)   ((WORD) (l))
@@ -107,7 +117,7 @@ enum MediaType
     mediaSpecial = 2,
     mediaGlossy = 3,
     mediaTransparency = 4,
-	mediaHighresPhoto = 5		// used by vip printers for 2400 mode
+    mediaHighresPhoto = 5       // used by vip printers for 2400 mode
 };
 
 
@@ -119,7 +129,7 @@ enum MediaSize
     sizeA4 = 26,
     sizeNum10Env = 81,
     sizePhoto = 74,             // 4x6 Index Card / Photo paper
-    sizeA6 = 73,				// used to be 24, full-bleed support is for 73 only. Is same size though
+    sizeA6 = 73,                // used to be 24, full-bleed support is for 73 only. Is same size though
     sizeB4 = 46,
     sizeB5 = 45,
     sizeOUFUKU = 72,
@@ -129,18 +139,21 @@ enum MediaSize
     sizeSuperB = 16,
     sizeLedger = 6,
     sizeFLSA = 10,
-    sizeExecutive = 1
+    sizeExecutive = 1,
+    sizeCustom = 101
 };
 
 
 //! \internal For use in connection with PCL media-source command.  Values are PCL codes.
 enum MediaSource
 {
+    sourceTrayMin = -2,
     sourceTray1 = 1,
 //  sourceTray2 = 4,        // no second tray in current supported list
     sourceManual = 2,
     sourceManualEnv = 3,
-	sourceTrayAuto = 7
+     sourceTrayAuto = 7,
+    sourceTrayMax = 50
 };
 
 
@@ -216,9 +229,10 @@ typedef enum              // typedef'ed for C interface
     A3 = 11,                        //!< 294 x 419.8 mm.
     A5 = 12,                        //!< 148 x 210 mm.
     LEDGER = 13,                    //!< 11 x 17 in.
-    SUPERB = 14,                    //!< 13 x 19 in.
+    SUPERB_SIZE = 14,               //!< 13 x 19 in.
     EXECUTIVE = 15,                 //!< 7.25 x 10.5 in.
     FLSA = 16,                      //!< 8.5 x 13 in.
+    CUSTOM_SIZE = 17,               //!< Custom
 #endif
     MAX_PAPER_SIZE                  //!< Only for array size and loops
 } PAPER_SIZE;
@@ -295,7 +309,7 @@ typedef enum                // typedef'ed for C interface
     QUALITY_NORMAL,         //!< Normal quality print mode (probably 300x300)
     QUALITY_DRAFT,          //!< Draft print mode - the same or faster then normal
     QUALITY_BEST,           //!< Probably slower and possible higher resolution
-	QUALITY_HIGHRES_PHOTO,	//!< 1200 dpi - currently 9xxvip, linux only
+    QUALITY_HIGHRES_PHOTO,  //!< 1200 dpi - currently 9xxvip, linux only
     MAX_QUALITY_MODE
 } QUALITY_MODE;
 
@@ -312,9 +326,9 @@ typedef enum               // typedef'ed for C interface
 //! PhotoTray status
 typedef enum
 {
-	UNKNOWN = -1,
-	DISENGAGED = 0,
-	ENGAGED = 1
+    UNKNOWN = -1,
+    DISENGAGED = 0,
+    ENGAGED = 1
 } PHOTOTRAY_STATE;
 
 //////////////////////////////////////////////////////////////////////////////////////
@@ -362,7 +376,8 @@ typedef enum                // typedef'ed for C interface
     WARN_FULL_BLEED_UNSUPPORTED = -6,//!< device does not support full-bleed printing
     WARN_FULL_BLEED_3SIDES = -7,     //!< full bleed on only 3 sides
     WARN_ILLEGAL_PAPERSIZE = -8,     //!< papersize illegal for given hardware
-	ILLEGAL_PAPERSIZE      = -8
+     ILLEGAL_PAPERSIZE      = -8,
+    WARN_INVALID_MEDIA_SOURCE = -9
 } DRIVER_ERROR; //DRIVER_ERROR
 
 
@@ -393,8 +408,8 @@ enum DISPLAY_STATUS
     DISPLAY_COMM_PROBLEM,
     DISPLAY_CANT_ID_PRINTER,
     DISPLAY_OUT_OF_PAPER_NEED_CONTINUE,
-	DISPLAY_PAPER_JAMMED,
-	DISPLAY_PHOTOTRAY_MISMATCH,
+    DISPLAY_PAPER_JAMMED,
+    DISPLAY_PHOTOTRAY_MISMATCH,
 
     // internal driver use only
 
