@@ -81,9 +81,10 @@ MediaSize PaperToMediaSize(PAPER_SIZE psize)
     case A3:        return sizeA3;      break;
     case A5:        return sizeA5;      break;
     case LEDGER:        return sizeLedger;      break;
-    case SUPERB:        return sizeSuperB;      break;
+    case SUPERB_SIZE:        return sizeSuperB;      break;
     case EXECUTIVE:     return sizeExecutive;   break;
-    case FLSA:          return sizeFLSA;        break;
+    case FLSA:          return sizeUSLegal;        break;
+    case CUSTOM_SIZE:   return sizeCustom;      break;
 #endif
     default:            return sizeUSLetter;    break;
     }
@@ -106,9 +107,10 @@ PAPER_SIZE MediaSizeToPaper(MediaSize msize)
     case sizeA3:    return A3;      break;
     case sizeA5:    return A5;      break;
     case sizeLedger:    return LEDGER;      break;
-    case sizeSuperB:    return SUPERB;      break;
+    case sizeSuperB:    return SUPERB_SIZE;      break;
     case sizeExecutive: return EXECUTIVE;   break;
     case sizeFLSA:      return FLSA;        break;
+    case sizeCustom:    return CUSTOM_SIZE; break;
 #endif
     default:            return UNSUPPORTED_SIZE; break;
     }
