@@ -1,7 +1,7 @@
 /*****************************************************************************\
     hpijs.cpp : HP Inkjet Server
 
-    Copyright (c) 2001 - 2002, Hewlett-Packard Co.
+    Copyright (c) 2001 - 2003, Hewlett-Packard Co.
     All rights reserved.
 
     Redistribution and use in source and binary forms, with or without
@@ -77,13 +77,10 @@ int hpijs_set_context(UXServices *pSS)
 
    if ((r = pSS->pPC->SelectPrintMode((QUALITY_MODE)pSS->Quality, (MEDIATYPE)pSS->MediaType, (COLORMODE)pSS->ColorMode)) !=  NO_ERROR)
    {
-      bug("unable to set Quality=%d, ColorMode=%d, MediaType=%d, err=%d\n", pSS->Quality, pSS->ColorMode, pSS->MediaType, r);
-      QUALITY_MODE   eQuality;
-      MEDIATYPE      eMedia;
-      COLORMODE      eColorMode;
       BOOL        bDevText;
-      pSS->pPC->GetPrintModeSettings (eQuality, eMedia, eColorMode, bDevText);
-      bug("following will be used Quality=%d, ColorMode=%d, MediaType=%d\n", eQuality, eColorMode, eMedia);
+      bug("unable to set Quality=%d, ColorMode=%d, MediaType=%d, err=%d\n", pSS->Quality, pSS->ColorMode, pSS->MediaType, r);
+      pSS->pPC->GetPrintModeSettings ((QUALITY_MODE)pSS->Quality, (MEDIATYPE)pSS->MediaType, (COLORMODE)pSS->ColorMode, bDevText);
+      bug("following will be used Quality=%d, ColorMode=%d, MediaType=%d\n", pSS->Quality, pSS->ColorMode, pSS->MediaType);
    }
 
    /* Map ghostscript paper size to APDK paper size. */
@@ -100,32 +97,63 @@ int hpijs_set_context(UXServices *pSS)
       if (pSS->pPC->SelectDuplexPrinting(DUPLEXMODE_TABLET) != TRUE)
          bug("unable to set duplex mode=tablet\n");
    }
+   else
+   {
+      pSS->pPC->SelectDuplexPrinting(DUPLEXMODE_NONE);
+   }
+
+   if (pSS->MediaPosition != sourceTrayAuto)
+   {
+      if (pSS->pPC->SetMediaSource((MediaSource)pSS->MediaPosition) != NO_ERROR)
+         bug("unable to set MediaPosition=%d\n", pSS->MediaPosition);
+   }
+
    return 0;
 }
 
 int hpijs_status_cb(void *status_cb_data, IjsServerCtx *ctx, IjsJobId job_id)
 {
-  return 0;
+   return 0;
 }
 
 int hpijs_list_cb(void *list_cb_data, IjsServerCtx *ctx, IjsJobId job_id,
         char *val_buf, int val_size)
 {
-  return 0;
+   return snprintf(val_buf, val_size, "OutputFD,DeviceManufacturer,DeviceModel,PageImageFormat,Dpi,Width,Height,BitsPerSample,ColorSpace,PaperSize,PrintableArea,PrintableTopLeft,PS:Duplex,PS:Tumble,Quality:Quality,Quality:MediaType,Quality:ColorMode,Quality:PenSet,Quality:FullBleed,PS:MediaPosition");
 }
 
 int hpijs_enum_cb(void *enum_cb_data, IjsServerCtx *ctx, IjsJobId job_id,
        const char *key, char *val_buf, int val_size)
 {
-  if (!strcmp (key, "ColorSpace"))
-    snprintf(val_buf, val_size, "%s", "sRGB");
-  else if (!strcmp (key, "DeviceManufacturer"))
-    snprintf(val_buf, val_size, "%s", "HEWLETT-PACKARD,APOLLO");
-  else if (!strcmp (key, "PageImageFormat"))
-    snprintf(val_buf, val_size, "%s", "Raster");
-  else
-    bug("unable to enum key=%s\n", key);    
-  return 0;
+   UXServices *pSS = (UXServices*)enum_cb_data;
+
+   if (!strcmp (key, "ColorSpace"))
+      return snprintf(val_buf, val_size, "sRGB");
+   else if (!strcmp (key, "DeviceManufacturer"))
+      return snprintf(val_buf, val_size, "HEWLETT-PACKARD,APOLLO,HP");
+   else if (!strcmp (key, "PageImageFormat"))
+      return snprintf(val_buf, val_size, "Raster");
+   else if (!strcmp (key, "BitsPerSample"))
+      return snprintf(val_buf, val_size, "8");
+   else if (!strcmp (key, "PS:Duplex"))
+   {
+      if (pSS->pPC->SelectDuplexPrinting(DUPLEXMODE_BOOK) == TRUE)
+         return snprintf(val_buf, val_size, "true");
+      else
+         return snprintf(val_buf, val_size, "false");
+      pSS->pPC->SelectDuplexPrinting(DUPLEXMODE_NONE);
+   }
+   else if (!strcmp (key, "PS:Tumble"))
+   {
+      if (pSS->pPC->SelectDuplexPrinting(DUPLEXMODE_TABLET) == TRUE)
+         return snprintf(val_buf, val_size, "true");
+      else
+         return snprintf(val_buf, val_size, "false");
+      pSS->pPC->SelectDuplexPrinting(DUPLEXMODE_NONE);
+   }
+   else
+      bug("unable to enum key=%s\n", key);    
+  return IJS_ERANGE;
 }
 
 /*
@@ -161,7 +189,8 @@ int hpijs_set_cb (void *set_cb_data, IjsServerCtx *ctx, IjsJobId job_id,
    }
    else if (!strcmp (key, "DeviceManufacturer"))
    {
-      if ((strncmp(svalue, "HEWLETT-PACKARD", 15) != 0) && (strncmp(svalue, "APOLLO", 6) != 0))
+      if ((strncasecmp(svalue, "HEWLETT-PACKARD", 15) != 0) &&
+         (strncasecmp(svalue, "APOLLO", 6) != 0) && (strncasecmp(svalue, "HP", 2) != 0))
       {
          bug("unable to set DeviceManufacturer=%s\n", svalue);
          status = -1;
@@ -183,6 +212,12 @@ int hpijs_set_cb (void *set_cb_data, IjsServerCtx *ctx, IjsJobId job_id,
          bug("unable to set device=%d, err=%d\n", pSS->Model, r);
          status = -1;
       }
+      else
+      {
+         /* Got a valid device class, let's set some print mode defaults. */
+         BOOL        bDevText;
+         pSS->pPC->GetPrintModeSettings ((QUALITY_MODE)pSS->Quality, (MEDIATYPE)pSS->MediaType, (COLORMODE)pSS->ColorMode, bDevText);
+      }
    }
    else if ((strcmp (key, "PS:Duplex") == 0) || (strcmp (key, "Duplex") == 0))
    {
@@ -208,7 +243,7 @@ int hpijs_set_cb (void *set_cb_data, IjsServerCtx *ctx, IjsJobId job_id,
          /* Normal start of print Job. */
          pSS->PaperWidth = w;
          pSS->PaperHeight = h;
-		   hpijs_set_context(pSS);
+         hpijs_set_context(pSS);
       }
       else
       {
@@ -218,7 +253,7 @@ int hpijs_set_cb (void *set_cb_data, IjsServerCtx *ctx, IjsJobId job_id,
             pSS->FirstRaster = 1;  /* force new Job */
             pSS->PaperWidth = w;   /* set new paper size */
             pSS->PaperHeight = h;
-		      hpijs_set_context(pSS);
+            hpijs_set_context(pSS);
          }
       }
    }
@@ -246,39 +281,54 @@ int hpijs_set_cb (void *set_cb_data, IjsServerCtx *ctx, IjsJobId job_id,
    {
       pSS->FullBleed = strtol(svalue, &tail, 10);
    }
+   else if (!strcmp (key, "PS:MediaPosition"))
+   {
+      pSS->MediaPosition = strtol(svalue, &tail, 10);
+   }
    else
       bug("unable to set key=%s, value=%s\n", key, svalue);    
 
    return status;
 }
 
-/* Get parameter (from the server) call back. Note, all calls must be preceded by set DeviceName.
- * For duplex mode top and bottom margins must be 0.5".  */
+/* Get parameter (from the server) call back. Note, all calls must be preceded by set DeviceName. */
 int hpijs_get_cb(void *get_cb_data, IjsServerCtx *ctx, IjsJobId job_id, const char *key, char *value_buf, int value_size)
 {
    UXServices *pSS = (UXServices*)get_cb_data;
 
    if (!strcmp (key, "PrintableArea"))
    {
-      if (pSS->pPC->QueryDuplexMode() != DUPLEXMODE_NONE)
+      /* If duplexing, adjust printable height to 1/2 inch top/bottom margins, except laserjets. */
+      if ((pSS->pPC->QueryDuplexMode() != DUPLEXMODE_NONE) && pSS->pPC->RotateImageForBackPage())
          return snprintf(value_buf, value_size, "%.4fx%.4f", pSS->pPC->PrintableWidth(), pSS->pPC->PhysicalPageSizeY()-1);
       else
          return snprintf(value_buf, value_size, "%.4fx%.4f", pSS->pPC->PrintableWidth(), pSS->pPC->PrintableHeight());
    }
    else if (!strcmp (key, "PrintableTopLeft"))
    {
-      if (pSS->pPC->QueryDuplexMode() != DUPLEXMODE_NONE)
+      /* If duplexing, adjust printable top to 1/2 inch top margin, except laserjets. */
+      if ((pSS->pPC->QueryDuplexMode() != DUPLEXMODE_NONE) && pSS->pPC->RotateImageForBackPage())
          return snprintf(value_buf, value_size, "%.4fx%.4f", pSS->pPC->PrintableStartX(), 0.5);
       else
          return snprintf(value_buf, value_size, "%.4fx%.4f", pSS->pPC->PrintableStartX(), pSS->pPC->PrintableStartY());
    }
-   else if (!strcmp (key, "Duplex"))
+   else if ((!strcmp (key, "Duplex")) || (!strcmp (key, "PS:Duplex")))
    {
-      return snprintf(value_buf, value_size, "%d", pSS->pPC->QueryDuplexMode());
+      if (pSS->pPC->QueryDuplexMode() == DUPLEXMODE_NONE)
+         return snprintf(value_buf, value_size, "false");
+      else
+         return snprintf(value_buf, value_size, "true");
+   }
+   else if ((!strcmp (key, "Tumble")) || (!strcmp (key, "PS:Tumble")))
+   {
+      if (pSS->pPC->QueryDuplexMode() == DUPLEXMODE_TABLET)
+         return snprintf(value_buf, value_size, "true");
+      else
+         return snprintf(value_buf, value_size, "false");
    }
    else if (!strcmp (key, "PaperSize"))
    {
-      return snprintf(value_buf, value_size, "%d", pSS->pPC->GetPaperSize());
+      return snprintf(value_buf, value_size, "%.4fx%.4f", pSS->pPC->PhysicalPageSizeX(), pSS->pPC->PhysicalPageSizeY());
    }
    else if (!strcmp (key, "Dpi"))
    {
@@ -286,14 +336,40 @@ int hpijs_get_cb(void *get_cb_data, IjsServerCtx *ctx, IjsJobId job_id, const ch
    }
    else if (!strcmp (key, "DeviceModel"))
    {
-      return snprintf(value_buf, value_size, "%d", pSS->pPC->SelectedDevice());
+      return snprintf(value_buf, value_size, "%s", pSS->pPC->PrintertypeToString((PRINTER_TYPE)pSS->Model));
+   }
+   else if (!strcmp (key, "Quality:Quality"))
+   {
+      return snprintf(value_buf, value_size, "%d", pSS->Quality);
+   }
+   else if (!strcmp (key, "Quality:ColorMode"))
+   {
+      return snprintf(value_buf, value_size, "%d", pSS->ColorMode);
+   }
+   else if (!strcmp (key, "Quality:MediaType"))
+   {
+      return snprintf(value_buf, value_size, "%d", pSS->MediaType);
+   }
+   else if (!strcmp (key, "ColorSpace"))
+   {
+      return snprintf(value_buf, value_size, "sRGB");
    }
    else if (!strcmp (key, "PageImageFormat"))
-      return snprintf(value_buf, value_size, "%s", "Raster");
+   {
+      return snprintf(value_buf, value_size, "Raster");
+   }
+   else if (!strcmp (key, "BitsPerSample"))
+   {
+      return snprintf(value_buf, value_size, "8");
+   }
+   else if (!strcmp (key, "PS:MediaPosition"))
+   {
+      return snprintf(value_buf, value_size, "%d", pSS->MediaPosition);
+   }
    else
       bug("unable to get key=%s\n", key);    
 
-   return 0;
+   return IJS_EUNKPARAM;
 }
 
 int white(unsigned char *data, int size)
@@ -342,7 +418,7 @@ int main(int argc, char *argv[])
       if ((arg[0] == '-') && (arg[1] == 'h'))
       {
          fprintf(stdout, "\nHewlett-Packard Co. Inkjet Server %s\n", VERSION);
-         fprintf(stdout, "Copyright (c) 2001-2002, Hewlett-Packard Co.\n");
+         fprintf(stdout, "Copyright (c) 2001-2003, Hewlett-Packard Co.\n");
          exit(0);
       }
    }
@@ -429,7 +505,7 @@ int main(int argc, char *argv[])
 
          if (pSS->pPC->QueryDuplexMode() != DUPLEXMODE_NONE)
          {
-            if (pSS->pPC->QueryDuplexMode() == DUPLEXMODE_BOOK)
+            if ((pSS->pPC->QueryDuplexMode() == DUPLEXMODE_BOOK) && pSS->pPC->RotateImageForBackPage())
                pSS->InitDuplexBuffer();
             pSS->BackPage = FALSE;
          }
@@ -439,6 +515,7 @@ int main(int argc, char *argv[])
          bug("EffResX=%d, EffResY=%d, InPixelsPerRow=%d, OutPixelsPerRow=%d\n", 
             pSS->pPC->EffectiveResolutionX(), pSS->pPC->EffectiveResolutionY(), 
             pSS->pPC->InputPixelsPerRow(), pSS->pPC->OutputPixelsPerRow());
+         bug("model=%s\n", pSS->pPC->PrintertypeToString(pSS->pPC->SelectedDevice()));
 #endif
       } // pSS->FirstRaster
 
@@ -463,7 +540,7 @@ int main(int argc, char *argv[])
 
       if (pSS->pPC->QueryDuplexMode() != DUPLEXMODE_NONE)
       {
-         if ((pSS->pPC->QueryDuplexMode() == DUPLEXMODE_BOOK) && pSS->BackPage)
+         if ((pSS->pPC->QueryDuplexMode() == DUPLEXMODE_BOOK) && pSS->pPC->RotateImageForBackPage() && pSS->BackPage)
          {
             pSS->SendBackPage();
          }
