@@ -293,8 +293,8 @@ public:
 ////////////////////////////////////////////////
 typedef struct
 {
-    const unsigned long *ulMap1;
-    const unsigned long *ulMap2;
+    const uint32_t *ulMap1;
+    const uint32_t *ulMap2;
 } ColorMap;
 
 
@@ -360,6 +360,21 @@ public:
     BOOL Process(BYTE* input, unsigned int size);
 }; //Mode2
 
+//ClassName
+//!
+/*
+\internal
+*/
+class Mode3 : public Compressor
+{
+public:
+    Mode3 (SystemServices* pSys, Printer *pPrinter, unsigned int RasterSize);
+    virtual ~Mode3 ();
+    BOOL Process (BYTE* input, unsigned int size);
+    void    Flush ();
+private:
+    Printer *m_pPrinter;
+}; //Mode3
 
 ////////////////////////////////////////////////////////////////////////////
 #if defined(APDK_FONTS_NEEDED)
@@ -490,7 +505,7 @@ protected:
     // escape sequence constants
     char SimpleColor[6]; BYTE sccount;      // color command string, and its size
     char mediatype[6]; BYTE mtcount;        // mediatype string, and its size
-    char mediasize[6]; BYTE mscount;        // mediasize string, and its size
+    char mediasize[8]; BYTE mscount;        // mediasize string, and its size
     char mediasource[6]; BYTE msrccount;    // mediasource string, and its size
     char quality[6]; BYTE qualcount;        // quality string, and its size
     BYTE QualityCode();         // returns just the variable byte of quality
@@ -584,6 +599,20 @@ protected:
 }; //Header895
 
 
+//ClassName
+/*
+******************************************************************************/
+class Header850 : public Header895
+{
+public:
+    Header850(Printer* p,PrintContext* pc);
+
+protected:
+    DRIVER_ERROR StartSend();
+
+}; //Header850
+
+
 //ClassName
 /*
 ******************************************************************************/
@@ -609,6 +638,7 @@ public:
     DRIVER_ERROR ConfigureImageData();
     DRIVER_ERROR Send();
     DRIVER_ERROR StartSend();
+    void SetMediaSource(MediaSource msource);
 }; //HeaderAladdin
 
 
@@ -634,6 +664,19 @@ public:
 }; //Header2xxx
 
 
+//ClassName
+/*
+******************************************************************************/
+class Header3320 : public Header
+{
+public:
+    Header3320 (Printer *p, PrintContext *pc);
+    DRIVER_ERROR Send ();
+protected:
+    DRIVER_ERROR EndJob ();
+    DRIVER_ERROR FormFeed ();
+    DRIVER_ERROR SendCAPy (unsigned int iAbsY);
+};
 //ClassName
 /*
 ******************************************************************************/
@@ -644,6 +687,53 @@ public:
     DRIVER_ERROR Send();
 };  //Header21xx
 
+//ClassName
+/*
+******************************************************************************/
+class HeaderLJMono : public Header
+{
+public:
+    HeaderLJMono (Printer* p,PrintContext* pc);
+    virtual DRIVER_ERROR Send();
+
+protected:
+    DRIVER_ERROR EndJob ();
+    DRIVER_ERROR Graphics ();
+    DRIVER_ERROR StartSend ();
+}; //HeaderLJMono
+
+//ClassName
+/*
+******************************************************************************/
+class HeaderLJColor : public Header
+{
+public:
+    HeaderLJColor (Printer* p,PrintContext* pc);
+    virtual DRIVER_ERROR Send();
+	virtual DRIVER_ERROR FormFeed ();
+
+protected:
+    DRIVER_ERROR EndJob ();
+    DRIVER_ERROR Graphics ();
+    DRIVER_ERROR StartSend ();
+    DRIVER_ERROR SendCAPy (unsigned int iAbsY);
+}; //HeaderLJMono
+
+//ClassName
+/*
+******************************************************************************/
+class HeaderPScript : public Header
+{
+public:
+    HeaderPScript (Printer *p, PrintContext *pc);
+    DRIVER_ERROR Send ();
+protected:
+    DRIVER_ERROR EndJob ();
+    DRIVER_ERROR FormFeed ();
+    DRIVER_ERROR SendCAPy (unsigned int iAbsY);
+    DRIVER_ERROR StartSend ();
+};
+
 //RasterSender
 //! Send rasters to the device
 /*!
@@ -677,7 +767,7 @@ private:
     PrintContext* thePrintContext;
     Job* theJob;
     Halftoner* theHalftoner;
-    long    m_lNBlankRasters;
+    long    m_lNBlankRasters;	/* XXX unused? */
 }; //RasterSender
 
 // end of RasterSender section ///////////////////////////////////////////////
