@@ -185,9 +185,9 @@ Job::Job
     theTextManager = NULL;
     if (CurrentMode->bFontCapable)
     {
-        unsigned int pixelsX = (unsigned int)(thePrintContext->printablewidth() *
+        unsigned int pixelsX = (unsigned int) (int) (thePrintContext->printablewidth() *
                                 CurrentMode->BaseResX);
-        unsigned int pixelsY = (unsigned int)(thePrintContext->printableheight() *
+        unsigned int pixelsY = (unsigned int) (int) (thePrintContext->printableheight() *
                                 CurrentMode->BaseResY);
 
         theTextManager=new TextManager( pText, pixelsX,pixelsY );
@@ -553,7 +553,7 @@ DRIVER_ERROR Job::InitScaler()
 
      float tempfactor = (float)numerator / (float)denominator;
      tempfactor *= 1000.0f;
-     ScaleFactor = (unsigned int)tempfactor;
+     ScaleFactor = (unsigned int) (int) tempfactor;
 
 // Two paths: if ResSynth included (proprietary path), then use it for the first doubling;
 //            otherwise do it all in PixelReplication phase
