@@ -44,7 +44,7 @@ eDJ600,     // DJ 600
 eDJ6xxPhoto,    // DJ 610
 eDJ630,     // DJ 630
 eDJ6xxPhoto,    // DJ 640
-eAP2xxx,     // DJ 656 - HP Bolt
+eDJ630, // eAP2xxx,     // DJ 656 - HP Bolt
 eDJ6xxPhoto,    // DJ 690
 eDJ6xx,     // DJ 660
 eDJ6xx,     // DJ 670
@@ -55,20 +55,34 @@ eDJ8x5,     // DJ 825
 eDJ8xx,     // DJ 830
 eDJ8x5,     // DJ 845
 eDJ8xx,     // DJ 840
+eDJ850,     // DJ 850
+eDJ850,     // DJ 870
 eDJ8xx,     // DJ 880
+eDJ890,     // DJ 890
 eDJ8xx,     // DJ 895
+eDJ9xx,     // DJ 916 - Thriftway Lite (Europe)
+eDJ9xx,     // DJ 920 - Thriftway Lite
 eDJ9xx,     // DJ 930
 eDJ9xx,     // DJ 94x
 eDJ9xx,     // DJ 950
 eDJ9xxVIP,  // DJ 960
 eDJ9xx,     // DJ 970
 eDJ9xxVIP,  // DJ 980
-eDJ9xxVIP,  // DJ 990
+eDJ9xxVIP,  // DJ 990, 995 (Jeeni)
+eDJ3320,    // DJ 3320 - Crossbow
+eDJ3320,    // DJ 3420 - Crossbow
+eDJ9xx,     // DJ 3810 - Subway
+eDJ9xx,     // DJ 3816 - Subway
+eDJ9xx,     // DJ 3820 - Subway
+eDJ9xx,     // DJ 3822 - Subway
+eDJ9xxVIP,  // DJ 6122 - Churchill
+eDJ9xxVIP,  // DJ 6127 - FDR
 eDJ6xx,     // e-printer
 eAP2xxx,    // Apollo P-22
 eAP21xx,    // Apollo P2000U
 eAP2560,    // Apollo P2500/2600
 eDJ350,     // DJ 350
+eDJGenericVIP,  // DJ 450
 eDJ9xx,     // PS P1000
 eDJ9xx,     // PS P1100
 eDJ9xxVIP,  // PS 1215
@@ -76,13 +90,21 @@ eDJ9xxVIP,  // PS 1218
 eDJ9xxVIP,  // PS 1115
 eDJ9xxVIP,  // PS 1315
 ePSP100,    // PS 100
-eDJ8xx,     // DJ 1125 - Young Einstein
+ePSP100,    // PS 130 - Underdog - like AtomAnt
+ePSP100,    // PS 230
+eDJGenericVIP,  // PS 7150 - Twister
+eDJGenericVIP,  // PS 7350 - Dorothy
+eDJGenericVIP,  // PS 7550
+eDJ9xx,     // DJ 1120 - Young Einstein
+eDJ9xx,     // DJ 1125 - Young Einstein
 eDJ9xx,     // DJ 1220 - Escher
 eDJ9xxVIP,  // DJ 2200, 2230, 2250, 2280 - Nobel
-eDJ9xx,     // DJ 920 - Thriftway Lite
-eDJ9xxVIP,  // DJ 995 - Jeeni
 eDJ9xxVIP,  // CP 1160 - Jupiter Pro
 eDJ9xxVIP,  // CP 1700 - Euler
+eDJGenericVIP,   // DJ 5550 - Newport
+eDJGenericVIP,   // DJ 5551 - Hayakuna Newport Japan version
+eLJMono,	// LaserJet 5P
+eLJColor,	// Color Lasers
 };
 
 char *ModelString[MAX_ID_STRING] = {
@@ -103,8 +125,13 @@ char *ModelString[MAX_ID_STRING] = {
 "DESKJET 83",
 "DESKJET 845",
 "DESKJET 84",
+"DESKJET 85",
+"DESKJET 87",
 "DESKJET 88",
+"DESKJET 890",
 "DESKJET 895",
+"DESKJET 91",
+"DESKJET 92",
 "DESKJET 93",
 "DESKJET 94",
 "DESKJET 95",
@@ -112,11 +139,20 @@ char *ModelString[MAX_ID_STRING] = {
 "DESKJET 97",
 "DESKJET 98",
 "DESKJET 99",
+"deskjet 3320",
+"deskjet 3420",
+"DESKJET 3810", // subway
+"DESKJET 3816", // subway
+"DESKJET 3820", // subway
+"DESKJET 3822", // subway
+"deskjet 6122", // Churchill
+"deskjet 6127", // FDR
 "e-printer e20",
 "APOLLO P-22",
 "P-2000U",  // yes, the P-2100 report itself as a P-2000
 "APOLLO P2500/2600",
 "DESKJET 350",
+"dj450",    // Portable printer
 "PHOTOSMART P1000",
 "PHOTOSMART P1100",
 "PHOTOSMART 1215",
@@ -124,13 +160,21 @@ char *ModelString[MAX_ID_STRING] = {
 "PHOTOSMART 1115",
 "PHOTOSMART 1315",
 "PHOTOSMART 100",
+"PHOTOSMART 130",
+"PHOTOSMART 230",
+"photosmart 7150",
+"photosmart 7350",
+"photosmart 7550",
+"DESKJET 1120",
 "DESKJET 1125",
 "DESKJET 1220",
 "HP BUSINESS INKJET 22",
-"DESKJET 92",
-"DESKJET 995",
 "cp1160",
 "cp1700",
+"deskjet 5550",
+"deskjet 5551",
+"HP LaserJet",
+"hp color LaserJet",
 };
 
 PRINTER_TYPE BuiltIn[]={    // must match PRINTER_TYPE enum order
@@ -152,12 +196,21 @@ PRINTER_TYPE BuiltIn[]={    // must match PRINTER_TYPE enum order
 #ifdef APDK_DJ8xx
     eDJ8xx,
 #endif
+#ifdef APDK_DJ850
+    eDJ850,
+#endif
+#ifdef APDK_DJ890
+    eDJ890,
+#endif
 #ifdef APDK_DJ9xx
     eDJ9xx,
 #endif
 #ifdef APDK_DJ9xxVIP
     eDJ9xxVIP,
 #endif
+#ifdef APDK_DJ3320
+    eDJ3320,
+#endif
 #ifdef APDK_DJ630
     eDJ630,
 #endif
@@ -179,9 +232,18 @@ PRINTER_TYPE BuiltIn[]={    // must match PRINTER_TYPE enum order
 #ifdef APDK_PSP100
     ePSP100,
 #endif
-#ifdef APDK_DJ9xxVIP
+#ifdef APDK_DJGENERICVIP
     eDJGenericVIP,
 #endif
+#ifdef APDK_LJMONO
+	eLJMono,
+#endif
+#ifdef APDK_LJCOLOR
+	eLJColor,
+#endif
+#ifdef APDK_PSCRIPT
+	ePScript,
+#endif
 };
 
 unsigned int BuiltInSize =
@@ -204,11 +266,21 @@ unsigned int BuiltInSize =
 #ifdef APDK_DJ8xx
     1 +
 #endif
+#ifdef APDK_DJ850
+    1 +
+#endif
+#ifdef APDK_DJ890
+    1 +
+#endif
 #ifdef APDK_DJ9xx
     1 +
 #endif
 #ifdef APDK_DJ9xxVIP
-    2 +
+    1 +
+#endif
+
+#ifdef APDK_DJ3320
+    1 +
 #endif
 
 #ifdef APDK_DJ8x5
@@ -231,6 +303,18 @@ unsigned int BuiltInSize =
 #endif
 #ifdef APDK_PSP100
     1 +
+#endif
+#ifdef APDK_DJGENERICVIP
+    1 +
+#endif
+#ifdef APDK_LJMONO
+	1 +
+#endif
+#ifdef APDK_LJCOLOR
+	1 +
+#endif
+#ifdef APDK_PSCRIPT
+	1 +
 #endif
     0
     ;
@@ -284,8 +368,28 @@ unsigned int modelbits()
 #ifdef APDK_PSP100
         bits = bits | 0x200;
 #endif
-#ifdef APDK_DJ9xxVIP
-        bits = bits | 0x80; // eDJGenericVIP
+
+#ifdef APDK_DJ3320
+        bits = bits | 0x100;
+#endif
+
+#ifdef APDK_DJGENERICVIP
+        bits = bits | 0x80;
+#endif
+#ifdef APDK_LJMONO
+		bits = bits | 0x40;
+#endif
+#ifdef APDK_LJCOLOR
+		bits = bits | 0x20;
+#endif
+#ifdef APDK_PSCRIPT
+		bits = bits | 0x10;
+#endif
+#ifdef APDK_DJ850
+      bits = bits | 0x8;
+#endif
+#ifdef APDK_DJ890
+      bits = bits | 0x4;
 #endif
         return bits;
 }
@@ -316,12 +420,21 @@ char* modelresult()
 #ifdef APDK_DJ8x5
         HP_strcat(mresult,ModelName[eDJ8x5]); HP_strcat(mresult," ");
 #endif
+#ifdef APDK_DJ850
+        HP_strcat(mresult,ModelName[eDJ850]); HP_strcat(mresult," ");
+#endif
+#ifdef APDK_DJ890
+        HP_strcat(mresult,ModelName[eDJ890]); HP_strcat(mresult," ");
+#endif
 #ifdef  APDK_DJ9xx
         HP_strcat(mresult,ModelName[eDJ9xx]); HP_strcat(mresult," ");
 #endif
 #ifdef APDK_DJ9xxVIP
         HP_strcat(mresult,ModelName[eDJ9xxVIP]); HP_strcat(mresult," ");
 #endif
+#ifdef APDK_DJ3320
+        HP_strcat (mresult, ModelName[eDJ3320]); HP_strcat (mresult, " ");
+#endif
 #ifdef APDK_DJ630
         HP_strcat(mresult,ModelName[eDJ630]); HP_strcat(mresult," ");
 #endif
@@ -340,8 +453,17 @@ char* modelresult()
 #ifdef APDK_PSP100
         HP_strcat(mresult,ModelName[ePSP100]); HP_strcat(mresult," ");
 #endif
-#ifdef APDK_DJ9xxVIP
+#ifdef APDK_DJGENERICVIP
         HP_strcat(mresult,ModelName[eDJGenericVIP]); HP_strcat(mresult," ");
+#endif
+#ifdef APDK_LJMONO
+        HP_strcat(mresult,ModelName[eLJMono]); HP_strcat(mresult," ");
+#endif
+#ifdef APDK_LJCOLOR
+        HP_strcat (mresult, ModelName[eLJColor]); HP_strcat(mresult," ");
+#endif
+#ifdef APDK_PSCRIPT
+		HP_strcat (mresult, ModelName[ePScript]); HP_strcat (mresult, " ");
 #endif
     return mresult;
 }
@@ -353,7 +475,7 @@ APDK_END_NAMESPACE
 #include "..\..\Harness\StdAfx.h"
 #include "modes.h"
 
-using namespace APDK_NAMESPACE;
+APDK_USING_NAMESPACE
 
 extern CString IDStrings[MAX_PRINTER_TYPE+1][MAX_PRINTMODES];
 
@@ -445,6 +567,16 @@ void InitIDStrings()
     IDStrings[eDJ9xxVIP][DEFAULTMODE_INDEX]=
         "MFG:HEWLETT-PACKARD;MDL:DESKJET 960C;CMD:MLC,PCL,PML;CLS:PRINTER;DES:Hewlett-Packard DeskJet 960C;SN:US04C3J02WLY;S:00808880800010002C1100046C2080026;P:0800,FL,B0;J;";
 
+//  Crossbow
+//  LP1 firmware reports itself as a dj990
+
+    IDStrings[eDJ3320][GRAYMODE_INDEX]      =
+    IDStrings[eDJ3320][DEFAULTMODE_INDEX]   =
+    IDStrings[eDJ3320][SPECIALMODE_INDEX]   =
+    IDStrings[eDJ3320][SPECIALMODE_INDEX+1] =
+        "MFG:HEWLETT-PACKARD;MDL:DESKJET 990C;CMD:MLC,PCL,PML;CLS:PRINTER;DES:Hewlett-Packard DeskJet 990C;SN:US04C3J02WLY;S:00808880800010002C100005DC200005F;P:0800,FL,B0;J;";
+
+
     IDStrings[eAP2560][GRAYMODE_INDEX]=      // black pen
         "MFG:APOLLO;MDL:APOLLO P2500/2600;CMD:MLC,PCL,PML;CLASS:PRINTER;DESCRIPTION:Apollo DeskJet 1200C;SERN:US87L2R046GP;VSTATUS:$CB0,ff,DN,IDLE,CUT,PH;";
     IDStrings[eAP2560][DEFAULTMODE_INDEX]=   // color pen only
