@@ -46,6 +46,8 @@ typedef enum PRINTER_TYPE               // typedef'ed for C interface
     eDJ6xx,
     eDJ6xxPhoto,
     eDJ8xx,
+    eDJ850,
+    eDJ890,
     eDJ9xx,
     eDJ9xxVIP,
     eDJ630,
@@ -55,7 +57,11 @@ typedef enum PRINTER_TYPE               // typedef'ed for C interface
     eDJ350,
     eDJ8x5,
     ePSP100,
+    eDJ3320,
     eDJGenericVIP,
+	eLJMono,
+	eLJColor,
+	ePScript,
     MAX_PRINTER_TYPE
 } PRINTER_TYPE;
 
@@ -68,6 +74,8 @@ const char ModelName[MAX_PRINTER_TYPE][11] =
     "DJ6xx",
     "DJ6xxPhoto",
     "DJ8xx",
+    "DJ850",
+    "DJ890",
     "DJ9xx",
     "DJ9xxVIP",
     "DJ630",
@@ -77,7 +85,11 @@ const char ModelName[MAX_PRINTER_TYPE][11] =
     "DJ350",
     "DJ8x5",
     "PS100",
-    "GenericVIP"
+    "DJ3320",
+    "GenericVIP",
+	"Mono Laser",
+	"ColorLaser",
+	"PostScript"
 };
 
 
@@ -103,8 +115,13 @@ enum DevIdIndex
     DEVID_MODEL_83X,
     DEVID_MODEL_845,
     DEVID_MODEL_84X,
+    DEVID_MODEL_850,
+    DEVID_MODEL_870,
     DEVID_MODEL_88X,
+    DEVID_MODEL_890,
     DEVID_MODEL_895,
+    DEVID_MODEL_91X,
+    DEVID_MODEL_92X,
     DEVID_MODEL_93X,
     DEVID_MODEL_94X,
     DEVID_MODEL_95X,
@@ -112,25 +129,42 @@ enum DevIdIndex
     DEVID_MODEL_97X,
     DEVID_MODEL_98X,
     DEVID_MODEL_99X,
+    DEVID_MODEL_3320,           // DJ 3320 - Crossbow
+    DEVID_MODEL_3420,           // DJ 3420 - Crossbow
+    DEVID_MODEL_3810,           // DJ 3810 - Subway
+    DEVID_MODEL_3816,           // DJ 3816 - Subway
+    DEVID_MODEL_3820,           // DJ 3820 - Subway
+    DEVID_MODEL_3822,           // DJ 3822 - Subway
+    DEVID_MODEL_6122,           // DJ 6122 - Churchill
+    DEVID_MODEL_6127,           // DJ 6127 - FDR
     DEVID_MODEL_E20,
     DEVID_MODEL_APOLLO_P22XX,
     DEVID_MODEL_APOLLO_P21XX,
     DEVID_MODEL_APOLLO_P2X00,    // Apollo 2500/2600
     DEVID_MODEL_350,
+    DEVID_MODEL_450,
     DEVID_MODEL_PS_P1000,
     DEVID_MODEL_PS_P1100,
     DEVID_MODEL_PS_P1215,
     DEVID_MODEL_PS_P1218,
     DEVID_MODEL_PS_P1115,
     DEVID_MODEL_PS_P1315,
-    DEVID_MODEL_PS_P100,            // AtomAnt
+    DEVID_MODEL_PS_P100,         // AtomAnt
+    DEVID_MODEL_PS_P130,         // Underdog (AtomAnt follow-on)
+    DEVID_MODEL_PS_230,
+    DEVID_MODEL_PS_7150,         // Twister
+    DEVID_MODEL_PS_7350,         // Dorothy
+    DEVID_MODEL_PS_7550,
+    DEVID_MODEL_1120,
     DEVID_MODEL_1125,
     DEVID_MODEL_1220,
     DEVID_MODEL_2250,
-    DEVID_MODEL_92X,
-    DEVID_MODEL_995,
-    DEVID_MODEL_CP_1160,            // CP 1160 - Jupiter Pro
-    DEVID_MODEL_CP_1700,             // CP 1700 - Euler
+    DEVID_MODEL_CP_1160,         // CP 1160 - Jupiter Pro
+    DEVID_MODEL_CP_1700,         // CP 1700 - Euler
+    DEVID_MODEL_5550,            // DJ 5550 - Newport
+    DEVID_MODEL_5551,            // DJ 5551 - Hayakuna
+	DEVID_MODEL_LJMONO,
+	DEVID_MODEL_LJCOLOR,
     MAX_ID_STRING
 };
 
