@@ -103,8 +103,24 @@ Printer::Printer
 
 #ifdef APDK_AUTODUPLEX
     bDuplexCapable = FALSE;
+    m_bRotateBackPage = TRUE;
 #endif
 
+/*
+ *  LaserJet printers do not send status via device id string. PJL is used to
+ *  get status.
+ *  REVISIT:    Do the same for Business Inkjets as well.
+ */
+
+    m_bStatusByPJL = FALSE;
+    char    *tmpStr;
+    if ((strstr ((char *) pSS->strDevID, "LaserJet")) &&
+        (tmpStr = strstr ((char *) pSS->strDevID, "CMD:")) &&
+        (tmpStr = strstr (tmpStr+4, "PJL")))
+    {
+        m_bStatusByPJL = TRUE;
+    }
+
 #if defined(APDK_FONTS_NEEDED)
     // create dummy font objects to be queried via EnumFont
     // these fonts used by all except DJ400
@@ -360,11 +376,11 @@ DRIVER_ERROR Printer::Encapsulate
 
     if (bLastPlane)
     {
-        scratchLen = sprintf (scratch, "\033*b%luW", size);
+        scratchLen = sprintf (scratch, "\033*b%uW", size);
     }
     else
     {
-        scratchLen = sprintf (scratch, "\033*b%luV", size);
+        scratchLen = sprintf (scratch, "\033*b%uV", size);
     }
     err = Send ((const BYTE*) scratch, scratchLen);
 
@@ -528,7 +544,10 @@ DRIVER_ERROR Printer::Send
         }
         else
         {
-            if((tmpStr = strstr((char*)DevIDBuffer + 2,";S:")))    // aladdin devID style
+            int     iVersion = pSS->GetVIPVersion ();
+
+            if((tmpStr = strstr((char*)DevIDBuffer + 2,";S:")) &&
+                iVersion < 6)    // aladdin devID style
             {
                 // point to PrinterState
 /*
@@ -537,18 +556,22 @@ DRIVER_ERROR Printer::Send
  *				Version 02 and onwards, report two additional bytes before pen info
  */
 
-				if (pSS->GetVIPVersion () < 3)
+				if (iVersion < 3)
 				{
 					tmpStr += 17;   // 3 for ";S:", 2 for version, 12 for features = 17
 				}
-				else
+				else if (iVersion < 5)
 				{
 					tmpStr += 19;	// 17 as above plus 1 for MaxPaperSize, 1 reserved = 19
 				}
+                else
+                {
+                    tmpStr += 23;   // Crystal added 4 more nibbles
+                }
 
                 BYTE b1=*tmpStr++;
                 BYTE b2=*tmpStr++;
-                if ((b1=='0') && (b2=='5'))     // 05 = cancel
+                if ((b1=='0') && (b2=='5') && iVersion <= 5)     // 05 = cancel
                 {
                     cancelcheck=TRUE;
                 }
@@ -596,8 +619,18 @@ DRIVER_ERROR Printer::Send
 //            return write_error;
 //        }
 
+        write_error = NO_ERROR;
+        eDisplayStatus = DISPLAY_PRINTING;
         if (residual == 0) // no more data to send this time
         {
+            if (m_bStatusByPJL)
+            {
+                status_reg = (BYTE) DISPLAY_PRINTING;
+                eDisplayStatus = ParseError (status_reg);
+                if (eDisplayStatus != DISPLAY_PRINTING)
+                    write_error = IO_ERROR;
+            }
+
             // did we want to transition out of slow poll?
             if ( (InSlowPollMode != 0) &&
                 (prev_residual > MIN_XFER_FOR_SLOW_POLL) )
@@ -605,7 +638,8 @@ DRIVER_ERROR Printer::Send
                 InSlowPollMode = 0;
                 iTotal_SLOW_POLL_Count = 0;
             }
-            break;  // out of while loop
+            if (write_error == NO_ERROR)
+                break;  // out of while loop
         }
 
 
@@ -668,20 +702,28 @@ DRIVER_ERROR Printer::Send
         }
 
 
-        if (write_error != NO_ERROR) // slow poll times exceeded
+        if (write_error != NO_ERROR || (m_bStatusByPJL && eDisplayStatus != DISPLAY_PRINTING))
+        // slow poll times exceeded
         // the printer isn't taking data so let's see what's wrong...
         {
             DBG1("Parsing possible error state...\n");
             error_displayed = TRUE;
 
-            // go get the status of the printer
-            if (IOMode.bStatus)
+            if (m_bStatusByPJL)
             {
-                pSS->GetStatusInfo(&status_reg);
+                status_reg = (BYTE) eDisplayStatus;
             }
+            else
+            {
+                // go get the status of the printer
+                if (IOMode.bStatus)
+                {
+                    pSS->GetStatusInfo(&status_reg);
+                }
 
-            // determine the error
-            eDisplayStatus = ParseError(status_reg);
+                // determine the error
+                eDisplayStatus = ParseError(status_reg);
+            }
 
             switch (eDisplayStatus)
             {
@@ -729,9 +771,16 @@ DRIVER_ERROR Printer::Send
                             return JOB_CANCELED;
                         }
 
-                        if (IOMode.bStatus)
+                        if (m_bStatusByPJL)
                         {
-                            pSS->GetStatusInfo(&status_reg);
+                            status_reg = (BYTE) eDisplayStatus;
+                        }
+                        else
+                        {
+                            if (IOMode.bStatus)
+                            {
+                                pSS->GetStatusInfo(&status_reg);
+                            }
                         }
 
                         eDisplayStatus = ParseError(status_reg);
@@ -770,9 +819,16 @@ DRIVER_ERROR Printer::Send
                             return JOB_CANCELED;
                         }
 
-                        if (IOMode.bStatus)
+                        if (m_bStatusByPJL)
                         {
-                            pSS->GetStatusInfo(&status_reg);
+                            status_reg = (BYTE) eDisplayStatus;
+                        }
+                        else
+                        {
+                            if (IOMode.bStatus)
+                            {
+                                pSS->GetStatusInfo(&status_reg);
+                            }
                         }
 
                         eDisplayStatus = ParseError(status_reg);
@@ -888,7 +944,7 @@ BOOL Printer::TopCoverOpen
         return FALSE;
     }
     else
-    if ( (pStr=strstr((char*)bDevIDBuff+2,";S:00")) )  // binary encoded device ID status (version 0)
+    if (( pStr = strstr ((char*) bDevIDBuff+2, ";S")))
     {
         if ( (*(pStr+5) == '9') )
         {
@@ -931,8 +987,8 @@ PrintMode* Printer::GetMode
 
 PrintMode::PrintMode
 (
-    unsigned long *map1,
-    unsigned long *map2
+    uint32_t *map1,
+    uint32_t *map2
 )
 {
     pmQuality = QUALITY_NORMAL;
@@ -1003,7 +1059,7 @@ PrintMode::PrintMode
 
 GrayMode::GrayMode
 (
-    unsigned long *map
+    uint32_t *map
 ) :
     PrintMode(map)
 // grayscale uses econo, 300, 1 bit
@@ -1017,7 +1073,7 @@ GrayMode::GrayMode
 
 CMYGrayMode::CMYGrayMode
 (
-    unsigned long *map
+    uint32_t *map
 ) :
     GrayMode(map)
 {
@@ -1029,7 +1085,7 @@ CMYGrayMode::CMYGrayMode
 
 KCMYGrayMode::KCMYGrayMode
 (
-    unsigned long *map
+    uint32_t *map
 ) :
     GrayMode(map)
 {
@@ -1076,6 +1132,14 @@ DRIVER_ERROR Printer::SetPenInfo
         {
             pStr += 21;     // get to the number of pens field - 14 byte feature field
         }
+        else if ((pStr = strstr((char*)pSS->strDevID + 2, ";S:04")))  // binary encoded device ID status (version 3)
+        {
+            pStr += 25;     // get to the number of pens field - 18 byte feature field
+        }
+        else if ((pSS->GetVIPVersion ()) > 5)
+        {
+            return NO_ERROR;
+        }
         else
         {
             TRACE("Printer::SetPenInfo - Unsupported DeviceID %s.\n", pSS->strDevID);
