@@ -73,7 +73,7 @@ friend class Tester;
 friend class DJGenericVIP;
 #endif
 public:
-   PrintMode(unsigned long *map1,unsigned long *map2=(unsigned long*)NULL);
+   PrintMode(uint32_t *map1,uint32_t *map2=(uint32_t*)NULL);
 
     BOOL Compatible(PEN_TYPE pens);
     inline BOOL ColorCompatible(COLORMODE color) { return (color == pmColor); }
@@ -148,7 +148,7 @@ protected:
 class GrayMode : public PrintMode
 {
 public:
-    GrayMode(unsigned long *map);
+    GrayMode(uint32_t *map);
 }; //GrayMode
 
 
@@ -159,7 +159,7 @@ public:
 class CMYGrayMode : public GrayMode
 {
 public:
-    CMYGrayMode(unsigned long *map);
+    CMYGrayMode(uint32_t *map);
 }; //CMYGrayMode
 
 //ClassName
@@ -169,7 +169,7 @@ public:
 class KCMYGrayMode : public GrayMode
 {
 public:
-    KCMYGrayMode(unsigned long *map);
+    KCMYGrayMode(uint32_t *map);
 }; //KCMYGrayMode
 
 //Printer
@@ -228,7 +228,7 @@ public:
 
     int iNumFonts;          // size of fontarray
     BOOL bCheckForCancelButton;
-    unsigned long ulBytesSentSinceCancelCheck;
+    unsigned long ulBytesSentSinceCancelCheck;	/* XXX unused? */
 
     virtual BOOL UseGUIMode(PrintMode* pPrintMode) { return FALSE; }
     virtual BOOL UseCMYK(unsigned int iPrintMode) { return TRUE;}
@@ -252,14 +252,14 @@ public:
     inline BOOL VIPPrinter() {return m_bVIPPrinter;}
 
     PEN_TYPE ePen;
-    unsigned long *CMYMap;
+    uint32_t *CMYMap;
 
     virtual DRIVER_ERROR CheckInkLevel() { return NO_ERROR; }
 
     virtual PEN_TYPE DefaultPenSet() { return BOTH_PENS; }
     // need ParsePenInfo to remember this
     PEN_TYPE ActualPens() { return ePen; }
-    DRIVER_ERROR SetPens(PEN_TYPE eNewPen);
+    virtual DRIVER_ERROR SetPens(PEN_TYPE eNewPen);
 
     // function to set PrintMode indices, which can't be done in base constructor
     // so is called from PrintContext::SelectDevice
@@ -317,6 +317,11 @@ public:
 
 #ifdef APDK_AUTODUPLEX
     BOOL    bDuplexCapable;
+    BOOL    RotateImageForBackPage ()
+    {
+        return m_bRotateBackPage;
+    };
+
 #endif
 
 protected:
@@ -343,8 +348,12 @@ protected:
     PrintMode* pMode[MAX_PRINTMODES];
     unsigned int ModeCount;
     BOOL m_bVIPPrinter;
+    BOOL m_bStatusByPJL;
+#ifdef  APDK_AUTODUPLEX
+    BOOL m_bRotateBackPage;
+#endif
 
-    virtual Printer& Printer::operator=(const Printer& rhs) {return *this;} // don't allow assignment
+    virtual Printer& operator=(const Printer& rhs) {return *this;} // don't allow assignment
 
 }; //Printer
 
