@@ -37,7 +37,7 @@
 
 APDK_BEGIN_NAMESPACE
 
-extern unsigned long ulMapVOLTAIRE_CCM_K[ 9 * 9 * 9 ];
+extern uint32_t ulMapVOLTAIRE_CCM_K[ 9 * 9 * 9 ];
 
 // PhotoSmart 100 - AtomAnt
 
