@@ -64,16 +64,27 @@
 #ifdef APDK_DJ8x5
 #include "dj8x5.h"
 #endif
+#ifdef APDK_DJ850
+#include "dj850.h"
+#endif
+#ifdef APDK_DJ890
+#include "dj890.h"
+#endif
 #ifdef APDK_DJ9xx
 #include "dj9xx.h"
 #endif
 #if defined(APDK_DJ9xxVIP) || defined(APDK_PSP100)
 #include "dj9xxvip.h"
+#endif
+#ifdef APDK_DJGENERICVIP
 #include "djgenericvip.h"
 #endif
 #ifdef APDK_PSP100
 #include "psp100.h"
 #endif
+#ifdef APDK_DJ3320
+#include "dj3320.h"
+#endif
 #if defined(APDK_APOLLO2XXX) || defined(APDK_APOLLO21XX) || defined(APDK_APOLLO2560)
 #include "apollo2xxx.h"
 #endif
@@ -168,14 +179,41 @@ DRIVER_ERROR DeviceRegistry::SelectDevice(char* model, int *pVIPVersion, char* p
 
     if (!match) // see if printer supports VIP, if so set compatible device
     {
-//        if (*pVIPVersion == 1)
-        if (*pVIPVersion > 0)
+        if (*pVIPVersion == 1)
+        {
+            match = TRUE;
+            device = eDJ9xxVIP;
+        }
+        else if (*pVIPVersion > 1)
         {
             match = TRUE;
             device = eDJGenericVIP; // eDJ9xxVIP;
         }
     }
 
+/*
+ *  See if this is a sleek (LIDIL) printer, or PostScript printer
+ */
+
+    if (!match)
+    {
+        BYTE DevIDBuffer[DevIDBuffSize];
+
+        err = pSS->GetDeviceID(DevIDBuffer, DevIDBuffSize, FALSE);
+        ERRCHECK;   // should be either NO_ERROR or BAD_DEVICE_ID
+        if ((strstr((const char *) DevIDBuffer+2,"CMD:LDL")))
+        {
+            device = eDJ3320;
+            match = TRUE;
+        }
+		char	*cmdStr = strstr ((const char *) DevIDBuffer+2, "CMD:");
+		if (!match && (strstr ((const char *) cmdStr+4, "POSTSCRIPT")))
+		{
+			device = ePScript;
+			match = TRUE;
+		}
+    }
+
     if (!match)
     {
     // The devID model string did not have a match for a known printer
@@ -183,6 +221,7 @@ DRIVER_ERROR DeviceRegistry::SelectDevice(char* model, int *pVIPVersion, char* p
 
         // if we don't have pen info (VSTATUS) it's presumably
         //  either sleek, DJ4xx or non-HP
+		device = UNSUPPORTED;
         if ( pens[0] != '\0' )
         {
             // Venice (and Broadway?) printers return penID $X0$X0
@@ -210,6 +249,14 @@ DRIVER_ERROR DeviceRegistry::SelectDevice(char* model, int *pVIPVersion, char* p
             // Arggghh.  The pen(s) COULD be missing
             do
             {
+
+//				Is this binary-encoded format?
+
+				if (pens[0] != '$')
+				{
+					break;
+				}
+
                 // get pen1 - penID format is $HB0$FC0
                 pen1=pens[1];
 
@@ -245,12 +292,28 @@ DRIVER_ERROR DeviceRegistry::SelectDevice(char* model, int *pVIPVersion, char* p
                         else if(pen2 == '\0')
                             pSS->DisplayPrinterStatus(DISPLAY_NO_PEN_DJ600);
 
+						// may be one-pen venice derivative
+						else if (pen2 == 'F')
+						{
+							device = eDJ8x5;
+							return NO_ERROR;
+						}
                         // 2-pen printer with BLACK missing
                         else pSS->DisplayPrinterStatus(DISPLAY_NO_BLACK_PEN);
                     }
                     // 2-pen printer with COLOR missing
                     else if(pen2 == 'A')
-                            pSS->DisplayPrinterStatus(DISPLAY_NO_COLOR_PEN);
+					{
+
+//						Hoobes, Zorro or Linus, possibly Phobos derivative
+
+						if (pen1 == 'H' || pen1 == 'Z' || pen1 == 'L')
+						{
+							device = eDJ8x5;
+							return NO_ERROR;
+						}
+                        pSS->DisplayPrinterStatus(DISPLAY_NO_COLOR_PEN);
+					}
 
                     if (pSS->BusyWait(500) == JOB_CANCELED)
                         return  JOB_CANCELED;
@@ -265,37 +328,37 @@ DRIVER_ERROR DeviceRegistry::SelectDevice(char* model, int *pVIPVersion, char* p
             // now that we have pens to look at, let's do the logic
             //  to instantiate the 'best-fit' driver
 
-            if(pen1 == 'H') // Hobbes (BLACK)
+            if (pen1 == 'H' || pen1 == 'Z' || pen1 == 'L') // Hobbes, Zorro, Linus (BLACK)
             {
                 // check for a 850/855/870
-                if(pen2 == 'M') device=UNSUPPORTED; // Monet (COLOR)
-
-                else if (strncmp(model,"DESKJET 890",11) == 0)
-                    device=UNSUPPORTED; // 890 has same pens as Venice!
-
-                else if(pen2 == 'N') device=eDJ9xx; // Chinook (COLOR)
-
+                if (pen2 == 'M')		// Monet (COLOR)
+					device = eDJ850;
+                else if (strncmp (model,"DESKJET 890",11) == 0)
+                    device=eDJ890; // 890 has same pens as Venice!
+                else if (pen2 == 'N')	// Chinook (COLOR)
+					device = eDJ9xx;
                 // It must be a Venice derivative or will hopefully at
                 // least recognize a Venice print mode
-                else device=eDJ8xx;
+                else
+					device = eDJ8xx;
             }
             else if(pen1 == 'C') // Candide (BLACK)
             {
                 // check for 1-pen printer
-                if(pen2 == '\0') device=eDJ600;
+                if (pen2 == '\0') device = eDJ600;
                 // must be a 2-pen 6xx-derivative
-                else device=eDJ6xx;
+                else device = eDJ6xx;
             }
             else if(pen1 == 'M') // Multi-dye load
             {
                 // must be a 690-derivative
-                device=eDJ6xxPhoto;
+                device = eDJ6xxPhoto;
             }
 
             // check for 540-style pens?
             //  D = Kukla color, E = Triad black
 
-            else device=UNSUPPORTED;
+//            else device=UNSUPPORTED;
         }
     }
 
@@ -403,6 +466,20 @@ DBG1("DR::InstantiateGeneral: device = ");
                      break;
 #endif
 
+#ifdef APDK_DJ850
+        case(eDJ850):
+                     DBG1("DJ850\n");
+                     p=new DJ850(pSS);
+                     break;
+#endif
+
+#ifdef APDK_DJ890
+        case(eDJ890):
+                     DBG1("DJ890\n");
+                     p=new DJ890(pSS);
+                     break;
+#endif
+ 
 #ifdef APDK_DJ9xx
             case(eDJ9xx):
                      DBG1("DJ9xx\n");
@@ -415,6 +492,9 @@ DBG1("DR::InstantiateGeneral: device = ");
                      DBG1("DJ9xxVIP\n");
                      p=new DJ9xxVIP(pSS);
                      break;
+#endif
+
+#ifdef APDK_DJGENERICVIP
             case (eDJGenericVIP):
                      DBG1("DJGenericVIP\n");
                      p = new DJGenericVIP (pSS);
@@ -428,6 +508,13 @@ DBG1("DR::InstantiateGeneral: device = ");
                 break;
 #endif
 
+#ifdef APDK_DJ3320
+            case (eDJ3320):
+                DBG1("DJ3320\n");
+                p = new DJ3320 (pSS);
+                break;
+#endif
+
 #ifdef APDK_APOLLO2XXX
             case(eAP2xxx):
                      DBG1("Apollo2xxx\n");
@@ -445,6 +532,24 @@ DBG1("DR::InstantiateGeneral: device = ");
                      DBG1("Apollo2560\n");
                      p=new Apollo2560(pSS);
                      break;
+#endif
+#ifdef APDK_LJMONO
+			case (eLJMono):
+					DBG1("LJMono\n");
+					p = new LJMono (pSS);
+					break;
+#endif
+#ifdef APDK_LJCOLOR
+			case (eLJColor):
+					DBG1("LJColor\n");
+					p = new LJColor (pSS);
+					break;
+#endif
+#ifdef APDK_PSCRIPT
+			case (ePScript):
+					DBG1("ePScript\n");
+					p = new PScript (pSS);
+					break;
 #endif
         default:
                      DBG1("UNSUPPORTED_PRINTER\n");
@@ -490,10 +595,10 @@ DRIVER_ERROR DeviceRegistry::ParseDevIDString(const char* sDevID, char* strModel
     // get the model name
     // - note: I'm setting pStr to the return of strstr
     //   so I need to increment past my search string
-    if ( (pStr = strstr(sDevID+2,"MODEL:")) )
+    if ( (pStr = (char *)strstr(sDevID+2,"MODEL:")) )
         pStr+=6;
     else
-        if ( (pStr=strstr(sDevID+2,"MDL:")) )
+        if ( (pStr=(char *)strstr(sDevID+2,"MDL:")) )
             pStr+=4;
         else return BAD_DEVICE_ID;
 
@@ -505,7 +610,7 @@ DRIVER_ERROR DeviceRegistry::ParseDevIDString(const char* sDevID, char* strModel
 
 
     // see if this printer support VIP or not
-    if ( (pStr=strstr(sDevID+2,";S:00")) )   // binary encoded device ID status (version 0)
+    if ( (pStr=(char *)strstr(sDevID+2,";S:00")) )   // binary encoded device ID status (version 0)
     {
         pStr += 15;     // get to the VIP support field (version of 0 == doesn't support VIP)
         if ((*pStr >= '0') && (*pStr <= '9'))
@@ -535,9 +640,11 @@ DRIVER_ERROR DeviceRegistry::ParseDevIDString(const char* sDevID, char* strModel
  *   2 nibbles for version number
  *  14 nibbles for feature state  (the 15th nibble from ';' is the vip flag
  *   2 nibbles for printer status
+ *
+ *  Crystal added 4 more nibbles to the option field.
  */
 
-    else if ((pStr = strstr (sDevID+2, ";S:")))
+    else if ((pStr = (char *)strstr (sDevID+2, ";S:")))
     {
         *pVIPVersion = 0;
         HEXTOINT (*(pStr+3), pVIPVersion);
@@ -559,7 +666,7 @@ DRIVER_ERROR DeviceRegistry::ParseDevIDString(const char* sDevID, char* strModel
     }
 
     // now get the pen info
-    if( (pStr=strstr(sDevID+2,"VSTATUS:")) )
+    if( (pStr=(char *)strstr(sDevID+2,"VSTATUS:")) )
     {
         pStr+=8;
         i=0;
@@ -567,8 +674,8 @@ DRIVER_ERROR DeviceRegistry::ParseDevIDString(const char* sDevID, char* strModel
             strPens[i] = pStr[i++];
         strPens[i] = '\0';
     }
-    else if ( (pStr = strstr(sDevID + 2, ";S:00")) ||   // binary encoded device ID status (version 0)
-             (pStr = strstr (sDevID + 2, ";S:")))  // Jupiter and later style
+    else if ( (pStr = (char *)strstr(sDevID + 2, ";S:00")) ||   // binary encoded device ID status (version 0)
+             (pStr = (char *)strstr (sDevID + 2, ";S:")))  // Jupiter and later style
     {
 
         int     iVersion = 0;
@@ -579,10 +686,14 @@ DRIVER_ERROR DeviceRegistry::ParseDevIDString(const char* sDevID, char* strModel
         {
             pStr += 19;     // get to the number of pens field
         }
-        else
+        else if (iVersion < 4)
         {
             pStr += 21;
         }
+        else
+        {
+            pStr += 25;
+        }
 
         // each supported pen has a block of 8 bytes of info so copy the number of pens byte
         // plus 8 bytes for each supported ped
