@@ -50,6 +50,56 @@ extern PRINTER_TYPE DevIDtoPT(unsigned int StringIndex);
 APDK_END_NAMESPACE
 #include "hpijs.h"
 
+/*
+ * For now OfficeJet support is Linux specific and requires HPOJ, so
+ * OfficeJet model strings go here instead of in the APDK.
+ */
+
+#define HPIJS_MAX_ID_STRING 19
+
+PRINTER_TYPE HpijsDevIDMap[HPIJS_MAX_ID_STRING] = {
+eDJ540,     // OfficeJet Series 300 series
+eDJ6xx,     // OfficeJet Series 500 series
+eDJ6xx,     // OfficeJet Series 600 series
+eDJ6xx,     // PSC 300 series
+eDJ6xx,     // OfficeJet Series 700 series
+eDJ8xx,     // OfficeJet T series
+eDJ9xx,     // OfficeJet K series
+eDJ9xx,     // OfficeJet V series
+eDJ850,     // OFFICEJET PRO 1150
+eDJ890,     // OFFICEJET PRO 1170/1175
+eDJ8xx,     // OFFICEJET R series
+eDJ9xx,     // OfficeJet G series
+eDJ8xx,     // PSC 500
+eDJ9xx,     // PSC 750
+eDJ9xx,     // PSC 900 series
+eDJGenericVIP,  // PSC 2100
+eDJGenericVIP,  // PSC 2150
+eDJGenericVIP,  // PSC 2200
+eDJ9xxVIP   // officejet d series
+};
+
+char *HpijsModelString[HPIJS_MAX_ID_STRING] = {
+"OfficeJet Series 3",
+"OfficeJet Series 5",
+"OfficeJet Series 6",
+"Printer/Scanner/Copier 3",
+"OfficeJet Series 7",
+"OfficeJet T",
+"OfficeJet K",
+"OfficeJet V",
+"OFFICEJET PRO 115",
+"OFFICEJET PRO 117",
+"OFFICEJET R",
+"OfficeJet G",
+"PSC 5",
+"PSC 7",
+"PSC 9",
+"PSC 2100",
+"PSC 2150",
+"PSC 2200",
+"officejet d"
+};
 
 int UXServices::InitDuplexBuffer()
 {
@@ -84,8 +134,7 @@ int UXServices::SendBackPage()
 
 int UXServices::ProcessRaster(char *raster)
 {
-    if (!BackPage || (pPC->QueryDuplexMode() != DUPLEXMODE_BOOK))
-
+    if (!((pPC->QueryDuplexMode() == DUPLEXMODE_BOOK) && pPC->RotateImageForBackPage() && BackPage))
         return pJob->SendRasters((unsigned char *)raster);
     else
     {
@@ -140,6 +189,7 @@ UXServices::UXServices():SystemServices()
    Tumble = 0;
    FullBleed = 0;
    FirstRaster = 1;
+   MediaPosition = sourceTrayAuto;
 }
 
 UXServices::~UXServices()
@@ -172,11 +222,25 @@ void UXServices::MapModel(const char *nam)
       if (!strncmp(nam,ModelString[i],strlen(ModelString[i])))
       {
          Model = DevIDtoPT(i);
-         break;
+         return;
       }
    }
+
+   for (i=0; i < HPIJS_MAX_ID_STRING; i++)
+   {
+      if (!strncmp(nam,HpijsModelString[i],strlen(HpijsModelString[i])))
+      {
+         Model = HpijsDevIDMap[i];
+         return;
+      }
+   }   
+
+   /* OfficeJet LX is not very unique, do separate check here. */
+   if (!strncmp(nam,"OfficeJet", 10))
+      Model = eDJ540;
 }
 
+#if 0
 int UXServices::MapPaperSize(float width, float height, int model)
 {
    int r, size;
@@ -184,11 +248,13 @@ int UXServices::MapPaperSize(float width, float height, int model)
    /* Map gs paper sizes to APDK paper sizes. */
 
    if (height >= 19)
-      size = SUPERB;
+      size = SUPERB_SIZE;
    else if (height >= 17)
       size = LEDGER;
    else if (height >= 16.52)   /* de-sensitized from 16.53 */
       size = A3;
+   else if (height >= 15.5)
+      size = CROSSBOW_COVER;
    else if (height >= 14.342)
       size = B4;
    else if (height >= 14)
@@ -225,4 +291,40 @@ int UXServices::MapPaperSize(float width, float height, int model)
 
    return 0; 
 }
+#endif
 
+int UXServices::MapPaperSize(float width, float height, int model)
+{
+   int i, r, size;
+   float dx, dy;
+
+   /* Map gs paper sizes to APDK paper sizes, or do custom. */
+   size = CUSTOM_SIZE;
+   for (i=0; i<MAX_PAPER_SIZE; i++)
+   {
+      r = pPC->SetPaperSize((PAPER_SIZE)i);
+
+      if (r > 0)
+         continue;
+
+      dx = width > pPC->PhysicalPageSizeX() ? width - pPC->PhysicalPageSizeX() : pPC->PhysicalPageSizeX() - width;
+      dy = height > pPC->PhysicalPageSizeY() ? height - pPC->PhysicalPageSizeY() :  pPC->PhysicalPageSizeY() - height;
+
+      if ((dx < 0.05) && (dy < 0.05))
+      {
+         size = i;   /* found standard paper size */
+         break;
+      }
+   }
+
+   if (size == CUSTOM_SIZE)
+      pPC->SetCustomSize(width, height);
+
+   if ((r = pPC->SetPaperSize((PAPER_SIZE)size, FullBleed)) != NO_ERROR)
+   {
+      bug("unable to set paper size=%d, err=%d\n", size, r);
+      return -1;
+   }
+
+   return 0; 
+}
