@@ -40,7 +40,7 @@ extern char *ModelString[MAX_ID_STRING];
 extern PRINTER_TYPE DevIDtoPT(unsigned int StringIndex);
 APDK_END_NAMESPACE
 
-using namespace APDK_NAMESPACE;
+APDK_USING_NAMESPACE
 
 class UXServices:public SystemServices
 {
@@ -137,7 +137,7 @@ public:
   int MediaType;     /* 0=plain, 1=premium, 2=photo */
   int ColorMode;     /* 0=grey_k, 1=grey_cmy, 2=color */
   int PenSet;        /* 0=black_pen, 1=color_pen, 2=both_pens, 3=mdl_pen, 4=mdl_both */
-  int MediaSource;
+  int MediaPosition;
   float PaperWidth;    /* physical width in inches */
   float PaperHeight;   /* physical height in inches */
   int Duplex;
